CompressionFormat

Enum CompressionFormat 

pub enum CompressionFormat {
    None,
    Lzma1,
    Lz4,
    Zstd,
}
Compression formats supported by TW Games.

Not all games support all formats. Check their game info to know what formats each game support.

Variants



None

Dummy variant to disable compression.



Lzma1

Legacy format. Supported by all PFH5 games (all Post-WH2 games).

Specifically, Total War games use the Non-Streamed LZMA1 format with the following custom header:

BytesTypeData
4u32Uncompressed size (as u32, max at 4GB).
1u8LZMA model properties (lc, lp, pb) in encoded form… I think. Usually it’s 0x5D.
4u32Dictionary size (as u32)… I think. It’s usually [0x00, 0x00, 0x40, 0x00].

For reference, a normal Non-Streamed LZMA1 header (from the original spec) contains:

BytesTypeData
1u8LZMA model properties (lc, lp, pb) in encoded form.
4u32Dictionary size (32-bit unsigned integer, little-endian).
8u64Uncompressed size (64-bit unsigned integer, little-endian).

This means one has to move the uncompressed size to the correct place in order for a compressed file to be readable, and one has to remove the uncompressed size and prepend it to the file in order for the game to read the compressed file.



Lz4

New format introduced in WH3 6.2.

This is a standard Lz4 implementation, with the following tweaks:

BytesTypeData
4u32Uncompressed size (as u32, max at 4GB).
*&[u8]Lz4 data, starting with the Lz4 Magic Number.


Zstd

New format introduced in WH3 6.2.

This is a standard Zstd implementation, with the following tweaks:

BytesTypeData
4u32Uncompressed size (as u32, max at 4GB).
*&[u8]Zstd data, starting with the Zstd Magic Number.

By default the Zstd compression is done with the checksum and content size flags enabled.