Compressible

Trait Compressible 

pub trait Compressible {
    // Required method
    fn compress(&self, format: CompressionFormat) -> Result<Vec<u8>>;
}
Internal trait to implement compression over a data type.

See also Decompressible for the reverse operation.

Required Methods

fn compress(&self, format: CompressionFormat) -> Result<Vec<u8>>

This function compress the data of a file, returning the compressed data.

Arguments
Returns

A Vec<u8> containing the compressed data, or an error if compression failed.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Compressible for [u8]

Implementors