pub struct Entry { /* private fields */ }Expand description
Represents a single animation entry within a fragment.
Contains all metadata and file references for one animation. The structure varies between version 2 and version 4 formats.
Version Differences
- Version 2: Uses direct filename and metadata strings
- Version 4: Uses
anim_refsfor multiple animation file references
Implementations
Sourceimpl Entry
impl Entry
Sourcepub fn animation_id(&self) -> &u32
pub fn animation_id(&self) -> &u32
Unique animation identifier.
Sourcepub fn blend_in_time(&self) -> &f32
pub fn blend_in_time(&self) -> &f32
Blend-in time in seconds for smooth transitions.
Sourcepub fn selection_weight(&self) -> &f32
pub fn selection_weight(&self) -> &f32
Selection weight for animation variation selection (higher = more likely).
Sourcepub fn weapon_bone(&self) -> &WeaponBone
pub fn weapon_bone(&self) -> &WeaponBone
Weapon attachment bone flags.
Sourcepub fn anim_refs(&self) -> &Vec<AnimRef>
pub fn anim_refs(&self) -> &Vec<AnimRef>
Animation file references (version 4 only).
Contains paths to animation data, metadata, and sound files.
Sourcepub fn metadata_sound(&self) -> &String
pub fn metadata_sound(&self) -> &String
Sound metadata file path (version 2 only).
Sourcepub fn skeleton_type(&self) -> &String
pub fn skeleton_type(&self) -> &String
Skeleton type identifier (version 2 only).
Sourcepub fn single_frame_variant(&self) -> &bool
pub fn single_frame_variant(&self) -> &bool
Whether this is a single-frame animation variant.
Sourceimpl Entry
impl Entry
Sourcepub fn animation_id_mut(&mut self) -> &mut u32
pub fn animation_id_mut(&mut self) -> &mut u32
Unique animation identifier.
Sourcepub fn blend_in_time_mut(&mut self) -> &mut f32
pub fn blend_in_time_mut(&mut self) -> &mut f32
Blend-in time in seconds for smooth transitions.
Sourcepub fn selection_weight_mut(&mut self) -> &mut f32
pub fn selection_weight_mut(&mut self) -> &mut f32
Selection weight for animation variation selection (higher = more likely).
Sourcepub fn weapon_bone_mut(&mut self) -> &mut WeaponBone
pub fn weapon_bone_mut(&mut self) -> &mut WeaponBone
Weapon attachment bone flags.
Sourcepub fn anim_refs_mut(&mut self) -> &mut Vec<AnimRef>
pub fn anim_refs_mut(&mut self) -> &mut Vec<AnimRef>
Animation file references (version 4 only).
Contains paths to animation data, metadata, and sound files.
Sourcepub fn slot_id_mut(&mut self) -> &mut u32
pub fn slot_id_mut(&mut self) -> &mut u32
Slot identifier (version 2 only).
Sourcepub fn filename_mut(&mut self) -> &mut String
pub fn filename_mut(&mut self) -> &mut String
Animation filename (version 2 only).
Sourcepub fn metadata_mut(&mut self) -> &mut String
pub fn metadata_mut(&mut self) -> &mut String
Metadata file path (version 2 only).
Sourcepub fn metadata_sound_mut(&mut self) -> &mut String
pub fn metadata_sound_mut(&mut self) -> &mut String
Sound metadata file path (version 2 only).
Sourcepub fn skeleton_type_mut(&mut self) -> &mut String
pub fn skeleton_type_mut(&mut self) -> &mut String
Skeleton type identifier (version 2 only).
Sourcepub fn uk_4_mut(&mut self) -> &mut String
pub fn uk_4_mut(&mut self) -> &mut String
Unknown field (purpose not identified, version 2 only).
Sourcepub fn single_frame_variant_mut(&mut self) -> &mut bool
pub fn single_frame_variant_mut(&mut self) -> &mut bool
Whether this is a single-frame animation variant.
Sourceimpl Entry
impl Entry
Sourcepub fn set_animation_id(&mut self, val: u32) -> &mut Self
pub fn set_animation_id(&mut self, val: u32) -> &mut Self
Unique animation identifier.
Sourcepub fn set_blend_in_time(&mut self, val: f32) -> &mut Self
pub fn set_blend_in_time(&mut self, val: f32) -> &mut Self
Blend-in time in seconds for smooth transitions.
Sourcepub fn set_selection_weight(&mut self, val: f32) -> &mut Self
pub fn set_selection_weight(&mut self, val: f32) -> &mut Self
Selection weight for animation variation selection (higher = more likely).
Sourcepub fn set_weapon_bone(&mut self, val: WeaponBone) -> &mut Self
pub fn set_weapon_bone(&mut self, val: WeaponBone) -> &mut Self
Weapon attachment bone flags.
Sourcepub fn set_anim_refs(&mut self, val: Vec<AnimRef>) -> &mut Self
pub fn set_anim_refs(&mut self, val: Vec<AnimRef>) -> &mut Self
Animation file references (version 4 only).
Contains paths to animation data, metadata, and sound files.
Sourcepub fn set_slot_id(&mut self, val: u32) -> &mut Self
pub fn set_slot_id(&mut self, val: u32) -> &mut Self
Slot identifier (version 2 only).
Sourcepub fn set_filename(&mut self, val: String) -> &mut Self
pub fn set_filename(&mut self, val: String) -> &mut Self
Animation filename (version 2 only).
Sourcepub fn set_metadata(&mut self, val: String) -> &mut Self
pub fn set_metadata(&mut self, val: String) -> &mut Self
Metadata file path (version 2 only).
Sourcepub fn set_metadata_sound(&mut self, val: String) -> &mut Self
pub fn set_metadata_sound(&mut self, val: String) -> &mut Self
Sound metadata file path (version 2 only).
Sourcepub fn set_skeleton_type(&mut self, val: String) -> &mut Self
pub fn set_skeleton_type(&mut self, val: String) -> &mut Self
Skeleton type identifier (version 2 only).
Sourcepub fn set_uk_3(&mut self, val: u32) -> &mut Self
pub fn set_uk_3(&mut self, val: u32) -> &mut Self
Unknown field (purpose not identified, version 2 only).
Sourcepub fn set_uk_4(&mut self, val: String) -> &mut Self
pub fn set_uk_4(&mut self, val: String) -> &mut Self
Unknown field (purpose not identified, version 2 only).
Sourcepub fn set_single_frame_variant(&mut self, val: bool) -> &mut Self
pub fn set_single_frame_variant(&mut self, val: bool) -> &mut Self
Whether this is a single-frame animation variant.