pub struct WeaponBone(/* private fields */);Expand description
Weapon attachment bone flags.
Defines which bones (attachment points) on the skeleton are used for weapon positioning during this animation. Multiple bones can be active simultaneously (e.g., for dual-wielding).
Bone Mapping
Each bit corresponds to a specific weapon attachment point:
WEAPON_BONE_1: Primary weapon hand (typically right hand)WEAPON_BONE_2: Secondary weapon hand (typically left hand)WEAPON_BONE_3: Back-mounted weapon (holstered)WEAPON_BONE_4: Additional attachment pointWEAPON_BONE_5: Additional attachment pointWEAPON_BONE_6: Additional attachment point
The exact bone mapping depends on the skeleton definition.
Implementations
Sourceimpl WeaponBone
impl WeaponBone
Sourcepub const WEAPON_BONE_1: Self
pub const WEAPON_BONE_1: Self
Primary weapon bone (bit 0).
Sourcepub const WEAPON_BONE_2: Self
pub const WEAPON_BONE_2: Self
Secondary weapon bone (bit 1).
Sourcepub const WEAPON_BONE_3: Self
pub const WEAPON_BONE_3: Self
Tertiary weapon bone (bit 2).
Sourcepub const WEAPON_BONE_4: Self
pub const WEAPON_BONE_4: Self
Fourth weapon bone (bit 3).
Sourcepub const WEAPON_BONE_5: Self
pub const WEAPON_BONE_5: Self
Fifth weapon bone (bit 4).
Sourcepub const WEAPON_BONE_6: Self
pub const WEAPON_BONE_6: Self
Sixth weapon bone (bit 5).
Sourceimpl WeaponBone
impl WeaponBone
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl WeaponBone
impl WeaponBone
Sourcepub const fn iter(&self) -> Iter<WeaponBone>
pub const fn iter(&self) -> Iter<WeaponBone>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WeaponBone>
pub const fn iter_names(&self) -> IterNames<WeaponBone>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.