pub struct BuildingReference { /* private fields */ }Expand description
Reference to a building by its index in the building list.
Provides a simple index-based reference to a building instance in the battlefield building list. Used by building links and other structures to refer to specific buildings.
Fields
serialise_version: Format version (currently only version 1)building_index: Index of the referenced building
Example
ⓘ
use rpfm_lib::files::bmd::common::building_reference::BuildingReference;
let mut reference = BuildingReference::default();
reference.set_serialise_version(1);
reference.set_building_index(42);Implementations
Sourceimpl BuildingReference
impl BuildingReference
Sourcepub fn serialise_version(&self) -> &u16
pub fn serialise_version(&self) -> &u16
Format version number (currently only version 1).
Sourcepub fn building_index(&self) -> &i32
pub fn building_index(&self) -> &i32
Index of the referenced building in the building list.
Sourceimpl BuildingReference
impl BuildingReference
Sourcepub fn serialise_version_mut(&mut self) -> &mut u16
pub fn serialise_version_mut(&mut self) -> &mut u16
Format version number (currently only version 1).
Sourcepub fn building_index_mut(&mut self) -> &mut i32
pub fn building_index_mut(&mut self) -> &mut i32
Index of the referenced building in the building list.
Sourceimpl BuildingReference
impl BuildingReference
Sourcepub fn set_serialise_version(&mut self, val: u16) -> &mut Self
pub fn set_serialise_version(&mut self, val: u16) -> &mut Self
Format version number (currently only version 1).
Sourcepub fn set_building_index(&mut self, val: i32) -> &mut Self
pub fn set_building_index(&mut self, val: i32) -> &mut Self
Index of the referenced building in the building list.