pub struct DockingLine { /* private fields */ }Expand description
Line where siege equipment can attach to walls.
Docking lines are required on walls for siege towers and ladders to attach. Without these, siege equipment cannot dock to the wall.
Fields
key- Key identifier for this docking linestart- Starting point of the lineend- Ending point of the linedirection- Direction vector for docking orientation