pub struct Gate { /* private fields */ }Expand description
Gate collision data for wall gates.
Defines the collision geometry for gates where units enter and exit cities. Contains two collision meshes, possibly for open and closed states.
Fields
collision_1- First collision meshcollision_2- Second collision meshuk_1- Unknown fielduk_2- Unknown field