pub struct Piece { /* private fields */ }Expand description
A piece of a building model with multiple destruction states.
Buildings are composed of multiple pieces, each with one or more destruction states (destructs). As a building takes damage, it transitions between these states.
Fields
name- Name identifier for this piecenode_name- Scene node name for attachmentnode_transform- Transformation matrix for positioningint_3- Unknown fieldint_4- Unknown field (only in v21)destructs- List of destruction states for this piecef_6- Unknown field
Examples
ⓘ
for piece in parsed.pieces() {
println!("Piece: {} ({} destructs)", piece.name(), piece.destructs().len());
}Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Piece
impl<'de> Deserialize<'de> for Piece
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Piece