pub struct Platform { /* private fields */ }Expand description
A walkable platform surface where units can stand and fight.
Platforms define the areas where units can be placed within a building. Different flags control how the pathfinder treats the platform.
Fields
normal- Surface normal vectorvertices- 3D outline defining the platform boundaryflag_1- Unknown behavior flagflag_2- Treats platform as ground if true (units can walk freely)flag_3- Unknown flag (set in siege tower ramp platforms)
Examples
ⓘ
for platform in destruct.platforms() {
if *platform.flag_2() {
println!("Platform '{}' is treated as ground", /* no name field */);
}
}Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Platform
impl<'de> Deserialize<'de> for Platform
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Platform