pub enum ContainerPath {
File(String),
Folder(String),
}Expand description
This enum represents a Path inside a Container.
Variants
File(String)
This variant represents the path of a single file.
Folder(String)
This variant represents the path of a single folder.
If this is empty, it represents the root of the container.
Implementations
Sourceimpl ContainerPath
impl ContainerPath
Sourcepub fn is_file(&self) -> bool
pub fn is_file(&self) -> bool
This function returns true if the provided ContainerPath corresponds to a file.
Sourcepub fn is_folder(&self) -> bool
pub fn is_folder(&self) -> bool
This function returns true if the provided ContainerPath corresponds to a folder.
Sourcepub fn is_pack(&self) -> bool
pub fn is_pack(&self) -> bool
This function returns true if the provided ContainerPath corresponds to a root Pack.
Sourcepub fn path_raw(&self) -> &str
pub fn path_raw(&self) -> &str
This function returns a reference to the path stored within the provided ContainerPath.
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
This function returns the last item of the provided ContainerPath, if any.
Sourcepub fn db_table_name_from_path(&self) -> Option<&str>
pub fn db_table_name_from_path(&self) -> Option<&str>
This function the table_name of this file (the folder that contains this file) if this file is a DB table.
It returns None of the file provided is not a DB Table.
Sourcepub fn parent_path(&self) -> String
pub fn parent_path(&self) -> String
This function returns the path of the parent folder of the provided ContainerPath.
If the provided ContainerPath corresponds to a Container root, the path returned will be the current one.
Sourcepub fn dedup(paths: &[Self]) -> Vec<Self>
pub fn dedup(paths: &[Self]) -> Vec<Self>
This function removes collided items from the provided list of ContainerPath.
This means, if you have a file and a folder containing the file, it removes the file.