RecordNodeFlags

Struct RecordNodeFlags 

pub struct RecordNodeFlags(/* private fields */);
Flags that control how a record node is encoded in the ESF binary format.

These flags are stored in the high bits of the type byte for record nodes. The combination of flags determines how the node header and children are encoded.

Binary Layout

For a record node’s first byte:

  • Bit 7 (0x80): Always set for record nodes (IS_RECORD_NODE)
  • Bit 6 (0x40): Set if node has nested blocks (HAS_NESTED_BLOCKS)
  • Bit 5 (0x20): Set if using non-optimized header format (HAS_NON_OPTIMIZED_INFO)
  • Bits 0-4: Used for optimized encoding of version/name when bit 5 is clear

Implementations

Source

impl RecordNodeFlags

pub const IS_RECORD_NODE: Self

Indicates this is a record node (container with children). This flag is always set for record nodes and distinguishes them from primitive nodes.

pub const HAS_NESTED_BLOCKS: Self

Indicates the record contains multiple groups of children (nested blocks). When set, children are organized into separate groups, each with its own size prefix. When clear, all children are in a single flat list.

pub const HAS_NON_OPTIMIZED_INFO: Self

Indicates the node uses the full 3-byte header format (u16 name index + u8 version). When clear, the header is compressed into 2 bytes using bitwise encoding:

  • Bits 1-4: Version (4 bits, max 15)
  • Bit 0 + next byte: Name index (9 bits, max 511)
Source

impl RecordNodeFlags

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u8

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u8) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u8) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u8) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl RecordNodeFlags

pub const fn iter(&self) -> Iter<RecordNodeFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<RecordNodeFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.