CUFProperties

Struct CUFProperties 

pub struct CUFProperties { /* private fields */ }
Font properties controlling text layout and rendering.

Many of these properties are indices or references whose exact purpose is still being researched. Comments from the Europa Barbarorum Team’s research have been preserved for reference.

Implementations

Source

impl CUFProperties

pub fn first_prop(&self) -> &u16

Unknown purpose (first CUF property).

pub fn second_prop(&self) -> &u16

Unknown purpose. Second CUF property.

pub fn line_height(&self) -> &u16

Index of the value which appears to have something to do with line height. Underscore line? Base line?

pub fn fourth_prop(&self) -> &u16

Unknown purpose. Fourth CUF property.

pub fn fifth_prop(&self) -> &u16

Unknown purpose. Fifth CUF property.

pub fn baseline(&self) -> &u16

Index of the value which appears to correspond to a ‘baseline’ of sorts in the CUF file format.

pub fn layout_y_offset(&self) -> &u16

Index of the value which determines y-offset w.r.t. the bounding box of a string of text in this font.

pub fn space_justify(&self) -> &u16

Used to specify how wide a space is for justification and text wrapping calculations.

pub fn layout_x_offset(&self) -> &u16

Index of the value which determines x-offset w.r.t. the bounding box of a string of text in this font.

pub fn h_size(&self) -> &u16

Index of the value which determines a maximum width for glyphs. Glyphs which are wider than the maximum specified for this property will appear cut-off.

There appears to be no effect on the position of a glyph after a glyph of which the advance is larger than the value specified for this setting.

Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.

pub fn v_size(&self) -> &u16

Index of the value which determines a maximum height for glyphs. The corresponding value probably should include leading. Glyphs which are taller than the maximum specified for this property will appear cut-off.

Too small values for this property may result in crashes or unspecified errors on exit in M2TW.

Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.

Source

impl CUFProperties

pub fn first_prop_mut(&mut self) -> &mut u16

Unknown purpose (first CUF property).

pub fn second_prop_mut(&mut self) -> &mut u16

Unknown purpose. Second CUF property.

pub fn line_height_mut(&mut self) -> &mut u16

Index of the value which appears to have something to do with line height. Underscore line? Base line?

pub fn fourth_prop_mut(&mut self) -> &mut u16

Unknown purpose. Fourth CUF property.

pub fn fifth_prop_mut(&mut self) -> &mut u16

Unknown purpose. Fifth CUF property.

pub fn baseline_mut(&mut self) -> &mut u16

Index of the value which appears to correspond to a ‘baseline’ of sorts in the CUF file format.

pub fn layout_y_offset_mut(&mut self) -> &mut u16

Index of the value which determines y-offset w.r.t. the bounding box of a string of text in this font.

pub fn space_justify_mut(&mut self) -> &mut u16

Used to specify how wide a space is for justification and text wrapping calculations.

pub fn layout_x_offset_mut(&mut self) -> &mut u16

Index of the value which determines x-offset w.r.t. the bounding box of a string of text in this font.

pub fn h_size_mut(&mut self) -> &mut u16

Index of the value which determines a maximum width for glyphs. Glyphs which are wider than the maximum specified for this property will appear cut-off.

There appears to be no effect on the position of a glyph after a glyph of which the advance is larger than the value specified for this setting.

Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.

pub fn v_size_mut(&mut self) -> &mut u16

Index of the value which determines a maximum height for glyphs. The corresponding value probably should include leading. Glyphs which are taller than the maximum specified for this property will appear cut-off.

Too small values for this property may result in crashes or unspecified errors on exit in M2TW.

Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.

Source

impl CUFProperties

pub fn set_first_prop(&mut self, val: u16) -> &mut Self

Unknown purpose (first CUF property).

pub fn set_second_prop(&mut self, val: u16) -> &mut Self

Unknown purpose. Second CUF property.

pub fn set_line_height(&mut self, val: u16) -> &mut Self

Index of the value which appears to have something to do with line height. Underscore line? Base line?

pub fn set_fourth_prop(&mut self, val: u16) -> &mut Self

Unknown purpose. Fourth CUF property.

pub fn set_fifth_prop(&mut self, val: u16) -> &mut Self

Unknown purpose. Fifth CUF property.

pub fn set_baseline(&mut self, val: u16) -> &mut Self

Index of the value which appears to correspond to a ‘baseline’ of sorts in the CUF file format.

pub fn set_layout_y_offset(&mut self, val: u16) -> &mut Self

Index of the value which determines y-offset w.r.t. the bounding box of a string of text in this font.

pub fn set_space_justify(&mut self, val: u16) -> &mut Self

Used to specify how wide a space is for justification and text wrapping calculations.

pub fn set_layout_x_offset(&mut self, val: u16) -> &mut Self

Index of the value which determines x-offset w.r.t. the bounding box of a string of text in this font.

pub fn set_h_size(&mut self, val: u16) -> &mut Self

Index of the value which determines a maximum width for glyphs. Glyphs which are wider than the maximum specified for this property will appear cut-off.

There appears to be no effect on the position of a glyph after a glyph of which the advance is larger than the value specified for this setting.

Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.

pub fn set_v_size(&mut self, val: u16) -> &mut Self

Index of the value which determines a maximum height for glyphs. The corresponding value probably should include leading. Glyphs which are taller than the maximum specified for this property will appear cut-off.

Too small values for this property may result in crashes or unspecified errors on exit in M2TW.

Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.