pub struct Font { /* private fields */ }Expand description
Represents a CUF font file.
Contains font properties, glyph data, and optional kerning information. Glyphs are stored in a sparse map indexed by character code (0-65535).
Implementations
Sourceimpl Font
impl Font
Sourcepub fn properties(&self) -> &CUFProperties
pub fn properties(&self) -> &CUFProperties
Font rendering properties and metrics.
Sourcepub fn glyphs(&self) -> &BTreeMap<u16, Glyph>
pub fn glyphs(&self) -> &BTreeMap<u16, Glyph>
Map of character codes to glyph data.
Only contains entries for characters actually defined in the font. Character codes map to Unicode-like values.
Sourcepub fn supports_kerning(&self) -> &bool
pub fn supports_kerning(&self) -> &bool
Whether this font file includes kerning data.
Sourcepub fn kerning_skip(&self) -> &u16
pub fn kerning_skip(&self) -> &u16
Character codes below this value do not have kerning data.
Sourcepub fn kerning_blocks(&self) -> &Vec<Vec<u8>>
pub fn kerning_blocks(&self) -> &Vec<Vec<u8>>
Kerning adjustment blocks (one per character code >= kerning_skip).
Sourceimpl Font
impl Font
Sourcepub fn properties_mut(&mut self) -> &mut CUFProperties
pub fn properties_mut(&mut self) -> &mut CUFProperties
Font rendering properties and metrics.
Sourcepub fn glyphs_mut(&mut self) -> &mut BTreeMap<u16, Glyph>
pub fn glyphs_mut(&mut self) -> &mut BTreeMap<u16, Glyph>
Map of character codes to glyph data.
Only contains entries for characters actually defined in the font. Character codes map to Unicode-like values.
Sourcepub fn supports_kerning_mut(&mut self) -> &mut bool
pub fn supports_kerning_mut(&mut self) -> &mut bool
Whether this font file includes kerning data.
Sourcepub fn kerning_skip_mut(&mut self) -> &mut u16
pub fn kerning_skip_mut(&mut self) -> &mut u16
Character codes below this value do not have kerning data.
Sourcepub fn kerning_blocks_mut(&mut self) -> &mut Vec<Vec<u8>>
pub fn kerning_blocks_mut(&mut self) -> &mut Vec<Vec<u8>>
Kerning adjustment blocks (one per character code >= kerning_skip).
Sourceimpl Font
impl Font
Sourcepub fn set_properties(&mut self, val: CUFProperties) -> &mut Self
pub fn set_properties(&mut self, val: CUFProperties) -> &mut Self
Font rendering properties and metrics.
Sourcepub fn set_glyphs(&mut self, val: BTreeMap<u16, Glyph>) -> &mut Self
pub fn set_glyphs(&mut self, val: BTreeMap<u16, Glyph>) -> &mut Self
Map of character codes to glyph data.
Only contains entries for characters actually defined in the font. Character codes map to Unicode-like values.
Sourcepub fn set_supports_kerning(&mut self, val: bool) -> &mut Self
pub fn set_supports_kerning(&mut self, val: bool) -> &mut Self
Whether this font file includes kerning data.
Sourcepub fn set_kerning_skip(&mut self, val: u16) -> &mut Self
pub fn set_kerning_skip(&mut self, val: u16) -> &mut Self
Character codes below this value do not have kerning data.
Sourcepub fn set_kerning_blocks(&mut self, val: Vec<Vec<u8>>) -> &mut Self
pub fn set_kerning_blocks(&mut self, val: Vec<Vec<u8>>) -> &mut Self
Kerning adjustment blocks (one per character code >= kerning_skip).