pub struct GroupFormation { /* private fields */ }Expand description
A single formation definition specifying how units should be arranged.
Each formation includes AI usage criteria, unit requirements, and a set of formation blocks that define where different unit types should be positioned.
Implementations
Sourceimpl GroupFormation
impl GroupFormation
Sourcepub fn ai_priority(&self) -> &f32
pub fn ai_priority(&self) -> &f32
AI priority value for selecting this formation (higher = more preferred).
Sourcepub fn ai_purpose(&self) -> &AIPurpose
pub fn ai_purpose(&self) -> &AIPurpose
Bitflags indicating when this formation should be used (attack, defend, naval, etc.).
Sourcepub fn min_unit_category_percentage(&self) -> &Vec<MinUnitCategoryPercentage>
pub fn min_unit_category_percentage(&self) -> &Vec<MinUnitCategoryPercentage>
Minimum percentage requirements for unit categories in this formation.
Sourcepub fn ai_supported_subcultures(&self) -> &Vec<String>
pub fn ai_supported_subcultures(&self) -> &Vec<String>
List of supported subcultures (introduced in Rome 2).
If non-empty, this formation is only available to armies from these subcultures.
Sourcepub fn ai_supported_factions(&self) -> &Vec<String>
pub fn ai_supported_factions(&self) -> &Vec<String>
List of supported factions (introduced in Rome 2).
If non-empty, this formation is only available to armies from these factions.
Sourcepub fn group_formation_blocks(&self) -> &Vec<GroupFormationBlock>
pub fn group_formation_blocks(&self) -> &Vec<GroupFormationBlock>
Formation blocks defining unit positions and arrangements.
Sourceimpl GroupFormation
impl GroupFormation
Sourcepub fn ai_priority_mut(&mut self) -> &mut f32
pub fn ai_priority_mut(&mut self) -> &mut f32
AI priority value for selecting this formation (higher = more preferred).
Sourcepub fn ai_purpose_mut(&mut self) -> &mut AIPurpose
pub fn ai_purpose_mut(&mut self) -> &mut AIPurpose
Bitflags indicating when this formation should be used (attack, defend, naval, etc.).
Sourcepub fn min_unit_category_percentage_mut(
&mut self,
) -> &mut Vec<MinUnitCategoryPercentage>
pub fn min_unit_category_percentage_mut( &mut self, ) -> &mut Vec<MinUnitCategoryPercentage>
Minimum percentage requirements for unit categories in this formation.
Sourcepub fn ai_supported_subcultures_mut(&mut self) -> &mut Vec<String>
pub fn ai_supported_subcultures_mut(&mut self) -> &mut Vec<String>
List of supported subcultures (introduced in Rome 2).
If non-empty, this formation is only available to armies from these subcultures.
Sourcepub fn ai_supported_factions_mut(&mut self) -> &mut Vec<String>
pub fn ai_supported_factions_mut(&mut self) -> &mut Vec<String>
List of supported factions (introduced in Rome 2).
If non-empty, this formation is only available to armies from these factions.
Sourcepub fn group_formation_blocks_mut(&mut self) -> &mut Vec<GroupFormationBlock>
pub fn group_formation_blocks_mut(&mut self) -> &mut Vec<GroupFormationBlock>
Formation blocks defining unit positions and arrangements.
Sourceimpl GroupFormation
impl GroupFormation
Sourcepub fn set_ai_priority(&mut self, val: f32) -> &mut Self
pub fn set_ai_priority(&mut self, val: f32) -> &mut Self
AI priority value for selecting this formation (higher = more preferred).
Sourcepub fn set_ai_purpose(&mut self, val: AIPurpose) -> &mut Self
pub fn set_ai_purpose(&mut self, val: AIPurpose) -> &mut Self
Bitflags indicating when this formation should be used (attack, defend, naval, etc.).
Sourcepub fn set_min_unit_category_percentage(
&mut self,
val: Vec<MinUnitCategoryPercentage>,
) -> &mut Self
pub fn set_min_unit_category_percentage( &mut self, val: Vec<MinUnitCategoryPercentage>, ) -> &mut Self
Minimum percentage requirements for unit categories in this formation.
Sourcepub fn set_ai_supported_subcultures(&mut self, val: Vec<String>) -> &mut Self
pub fn set_ai_supported_subcultures(&mut self, val: Vec<String>) -> &mut Self
List of supported subcultures (introduced in Rome 2).
If non-empty, this formation is only available to armies from these subcultures.
Sourcepub fn set_ai_supported_factions(&mut self, val: Vec<String>) -> &mut Self
pub fn set_ai_supported_factions(&mut self, val: Vec<String>) -> &mut Self
List of supported factions (introduced in Rome 2).
If non-empty, this formation is only available to armies from these factions.
Sourcepub fn set_group_formation_blocks(
&mut self,
val: Vec<GroupFormationBlock>,
) -> &mut Self
pub fn set_group_formation_blocks( &mut self, val: Vec<GroupFormationBlock>, ) -> &mut Self
Formation blocks defining unit positions and arrangements.