pub struct GroupFormations { /* private fields */ }Expand description
Represents an entire Group Formations file decoded in memory.
Contains a list of formation templates that both AI and players can use to deploy armies on the battlefield for various tactical scenarios.
Implementations
Sourceimpl GroupFormations
impl GroupFormations
Sourcepub fn formations(&self) -> &Vec<GroupFormation>
pub fn formations(&self) -> &Vec<GroupFormation>
List of all formation definitions in the file.
Sourceimpl GroupFormations
impl GroupFormations
Sourcepub fn formations_mut(&mut self) -> &mut Vec<GroupFormation>
pub fn formations_mut(&mut self) -> &mut Vec<GroupFormation>
List of all formation definitions in the file.
Sourceimpl GroupFormations
impl GroupFormations
Sourcepub fn set_formations(&mut self, val: Vec<GroupFormation>) -> &mut Self
pub fn set_formations(&mut self, val: Vec<GroupFormation>) -> &mut Self
List of all formation definitions in the file.