pub struct Spanning { /* private fields */ }Expand description
A spanning block that encompasses multiple other blocks.
Used to group related blocks together for organization or special handling.
Implementations
Sourceimpl Spanning
impl Spanning
Sourcepub fn spanned_block_ids(&self) -> &Vec<u32>
pub fn spanned_block_ids(&self) -> &Vec<u32>
IDs of the blocks that this spanning block encompasses.