pub struct AIPurposeFlags(/* private fields */);Implementations
Sourceimpl AIPurposeFlags
impl AIPurposeFlags
pub const ATTACK: Self
pub const DEFEND: Self
pub const RIVER_ATTACK: Self
pub const UK_3: Self
pub const UK_4: Self
pub const NAVAL_ATTACK: Self
pub const NAVAL_DEFEND: Self
pub const DEFAULT_DEPLOYMENT: Self
pub const NAVAL_DEFAULT_DEPLOYMENT: Self
pub const LARGE_MAP_ONLY: Self
pub const UK_10: Self
pub const UK_11: Self
pub const UK_12: Self
pub const UK_13: Self
pub const UK_14: Self
pub const UK_15: Self
pub const UK_16: Self
pub const UK_17: Self
pub const UK_18: Self
pub const UK_19: Self
pub const UK_20: Self
pub const UK_21: Self
pub const UK_22: Self
pub const UK_23: Self
pub const UK_24: Self
pub const UK_25: Self
pub const UK_26: Self
pub const UK_27: Self
pub const UK_28: Self
pub const UK_29: Self
pub const UK_30: Self
pub const UK_31: Self
Sourceimpl AIPurposeFlags
impl AIPurposeFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AIPurposeFlags
impl AIPurposeFlags
Sourcepub const fn iter(&self) -> Iter<AIPurposeFlags>
pub const fn iter(&self) -> Iter<AIPurposeFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AIPurposeFlags>
pub const fn iter_names(&self) -> IterNames<AIPurposeFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.