#[repr(u32)]pub enum StateParticipant {
Alive = 0,
Dead = 1,
NoIdea1 = 2,
NoIdea2 = 3,
NoIdea3 = 4,
NoIdea4 = 5,
NoIdea5 = 6,
}Expand description
Possible states for a participant in a matched combat animation.
Indicates whether the participant is alive, dead, or in some other state at the beginning or end of the animation sequence.
Variants
Alive = 0
Participant is alive and active.
Dead = 1
Participant is dead or dying.
NoIdea1 = 2
Unknown state variant.
NoIdea2 = 3
Unknown state variant.
NoIdea3 = 4
Unknown state variant.
NoIdea4 = 5
Unknown state variant.
NoIdea5 = 6
Unknown state variant.