EntityBundle

Struct EntityBundle 

pub struct EntityBundle { /* private fields */ }
A bundle of animation entities that can be selected together.

Allows the game to randomly choose between different animation variations based on selection weights, providing visual variety in combat.

Implementations

Source

impl EntityBundle

pub fn entities(&self) -> &Vec<Entity>

Animation entities in this bundle.

pub fn selection_weight(&self) -> &f32

Weight for random selection of this bundle (higher = more likely to be chosen).

Source

impl EntityBundle

pub fn set_entities(&mut self, val: Vec<Entity>) -> &mut Self

Animation entities in this bundle.

pub fn set_selection_weight(&mut self, val: f32) -> &mut Self

Weight for random selection of this bundle (higher = more likely to be chosen).