pub struct State { /* private fields */ }Expand description
State transition for a participant during the matched combat sequence.
Defines how the participant’s state changes from the start to the end of the animation (e.g., alive to dead for an execution animation, alive to alive for a non-lethal clash).
Implementations
Sourceimpl State
impl State
Sourcepub fn start(&self) -> &StateParticipant
pub fn start(&self) -> &StateParticipant
State at the beginning of the animation.
Sourcepub fn end(&self) -> &StateParticipant
pub fn end(&self) -> &StateParticipant
State at the end of the animation.
Sourceimpl State
impl State
Sourcepub fn set_start(&mut self, val: StateParticipant) -> &mut Self
pub fn set_start(&mut self, val: StateParticipant) -> &mut Self
State at the beginning of the animation.
Sourcepub fn set_end(&mut self, val: StateParticipant) -> &mut Self
pub fn set_end(&mut self, val: StateParticipant) -> &mut Self
State at the end of the animation.