PackHeader

Struct PackHeader 

pub struct PackHeader { /* private fields */ }
Header of a Pack, containing all the header-related info of said Pack.

Header Structure.

BytesTypeData
800-Padded StringU8Fake Preamble/Id of this Pack. Usually “MFH” and a bunch of 00. Only in old Steam Workshop files.
4StringU8Preamble/Id of this Pack. Contains the “version” of this Pack.
4u32Pack Type + Bitwised flags for tweaking certain Pack configurations.
4u32Amount of items in the Pack Index of this Pack.
4u32Lenght in bytes of the Pack Index.
4u32Amount of items in the File Index of this Pack.
4u32Lenght in bytes of the File Index.
8u64Timestamp when this Pack was last edited. Only in PFH2 and PFH3.
20Vec<u8>Extended header data. Only if HAS_EXTENDED_HEADER flag is set.
280SubheaderSubheader data. Only since PFH6.

Subheader Structure.

Subheader containing extra metadata for the Pack. Only in PFH6.

BytesTypeData
4u32Subheader marker. Marks the begining of the subheader. If missing, there’s no subheader.
4u32Subheader version.
4u32Game version this Pack was done for.
4u32Build number of the game version this Pack was done for.
800-Padded StringU8Tool that made this Pack.
256Vec<u8>Unused bytes.

Implementations

Source

impl PackHeader

pub fn pfh_version(&self) -> &PFHVersion

The version of the Pack.

pub fn pfh_file_type(&self) -> &PFHFileType

The type of the Pack.

pub fn bitmask(&self) -> &PFHFlags

The bitmasks applied to the Pack.

pub fn internal_timestamp(&self) -> &u64

The timestamp of the last time the Pack was saved.

pub fn game_version(&self) -> &u32

Game version this Pack is intended for. This usually triggers the “outdated mod” warning in the launcher if it doesn’t match the current exe version.

pub fn build_number(&self) -> &u32

Build number of the game.

pub fn authoring_tool(&self) -> &String

Tool that created the Pack. Max 8 characters, 00-padded.

pub fn extra_subheader_data(&self) -> &Vec<u8>

Extra subheader data, in case it’s used in the future.

Source

impl PackHeader

pub fn set_pfh_version(&mut self, val: PFHVersion) -> &mut Self

The version of the Pack.

pub fn set_pfh_file_type(&mut self, val: PFHFileType) -> &mut Self

The type of the Pack.

pub fn set_bitmask(&mut self, val: PFHFlags) -> &mut Self

The bitmasks applied to the Pack.

pub fn set_internal_timestamp(&mut self, val: u64) -> &mut Self

The timestamp of the last time the Pack was saved.

pub fn set_game_version(&mut self, val: u32) -> &mut Self

Game version this Pack is intended for. This usually triggers the “outdated mod” warning in the launcher if it doesn’t match the current exe version.

pub fn set_build_number(&mut self, val: u32) -> &mut Self

Build number of the game.

pub fn set_authoring_tool(&mut self, val: String) -> &mut Self

Tool that created the Pack. Max 8 characters, 00-padded.

pub fn set_extra_subheader_data(&mut self, val: Vec<u8>) -> &mut Self

Extra subheader data, in case it’s used in the future.