pub struct PackNotes { /* private fields */ }Expand description
Pack notes for documentation and collaboration.
Notes are stored within the pack and include both pack-level notes (general documentation) and file-specific notes (annotations on individual files or tables). Notes are serialized as JSON and can be shared when the pack is distributed.
Implementations
Sourceimpl PackNotes
impl PackNotes
Sourcepub fn pack_notes(&self) -> &String
pub fn pack_notes(&self) -> &String
General notes for the entire pack (Markdown format).
Sourceimpl PackNotes
impl PackNotes
Sourcepub fn pack_notes_mut(&mut self) -> &mut String
pub fn pack_notes_mut(&mut self) -> &mut String
General notes for the entire pack (Markdown format).
Sourceimpl PackNotes
impl PackNotes
Sourcepub fn set_pack_notes(&mut self, val: String) -> &mut Self
pub fn set_pack_notes(&mut self, val: String) -> &mut Self
General notes for the entire pack (Markdown format).
Sourceimpl PackNotes
impl PackNotes
Sourcepub fn load(data: &[u8]) -> Result<Self>
pub fn load(data: &[u8]) -> Result<Self>
This function tries to load the notes from the current Pack and return them.
Sourcepub fn notes_by_path(&self, path: &str) -> Vec<Note>
pub fn notes_by_path(&self, path: &str) -> Vec<Note>
This function returns all notes afecting the provided path.
Sourcepub fn add_note(&mut self, note: Note) -> Note
pub fn add_note(&mut self, note: Note) -> Note
This function adds a note for an specific path.
Note: for DB tables, notes are added for all tables with the same table name instead of specific tables.
Sourcepub fn delete_note(&mut self, path: &str, id: u64)
pub fn delete_note(&mut self, path: &str, id: u64)
This function deletes a note with the specified path and id.