PackSettings

Struct PackSettings 

pub struct PackSettings { /* private fields */ }
Pack-specific settings stored within the pack itself.

These settings are serialized to a reserved file within the pack, allowing them to be shared when the pack is distributed. Common settings include compression format, diagnostic ignore lists, and import configurations.

Built-in Settings

  • compression_format: The compression format to use (None, Lz4, Zlib)
  • diagnostics_files_to_ignore: Files/diagnostics to skip during validation
  • import_files_to_ignore: Files to skip during folder imports
  • disable_autosaves: Disable automatic saving
  • do_not_generate_existing_locs: Skip generating loc entries that already exist

Implementations

Source

impl PackSettings

pub fn settings_text(&self) -> &BTreeMap<String, String>

Multi-line text settings (e.g., file ignore lists).

pub fn settings_string(&self) -> &BTreeMap<String, String>

Single-line string settings (e.g., compression format).

pub fn settings_bool(&self) -> &BTreeMap<String, bool>

Boolean flag settings (e.g., disable_autosaves).

pub fn settings_number(&self) -> &BTreeMap<String, i32>

Integer settings (e.g., thresholds, limits).

Source

impl PackSettings

pub fn settings_text_mut(&mut self) -> &mut BTreeMap<String, String>

Multi-line text settings (e.g., file ignore lists).

pub fn settings_string_mut(&mut self) -> &mut BTreeMap<String, String>

Single-line string settings (e.g., compression format).

pub fn settings_bool_mut(&mut self) -> &mut BTreeMap<String, bool>

Boolean flag settings (e.g., disable_autosaves).

pub fn settings_number_mut(&mut self) -> &mut BTreeMap<String, i32>

Integer settings (e.g., thresholds, limits).

Source

impl PackSettings

pub fn set_settings_text(&mut self, val: BTreeMap<String, String>) -> &mut Self

Multi-line text settings (e.g., file ignore lists).

pub fn set_settings_string( &mut self, val: BTreeMap<String, String>, ) -> &mut Self

Single-line string settings (e.g., compression format).

pub fn set_settings_bool(&mut self, val: BTreeMap<String, bool>) -> &mut Self

Boolean flag settings (e.g., disable_autosaves).

pub fn set_settings_number(&mut self, val: BTreeMap<String, i32>) -> &mut Self

Integer settings (e.g., thresholds, limits).

Source

impl PackSettings

pub fn load(data: &[u8]) -> Result<Self>

This function tries to load the settings from a slice and return them.

pub fn load_and_update(&mut self, data: &[u8]) -> Result<()>

This function tries to load the settings from a slice, update them so they don’t have any missing values and return them.

pub fn setting_string(&self, key: &str) -> Option<&String>

This function returns the provided string setting, if found.

pub fn setting_text(&self, key: &str) -> Option<&String>

This function returns the provided text setting (multiline string), if found.

pub fn setting_bool(&self, key: &str) -> Option<&bool>

This function returns the provided bool setting, if found.

pub fn setting_number(&self, key: &str) -> Option<&i32>

This function returns the provided numeric setting, if found.

pub fn set_setting_string(&mut self, key: &str, value: &str)

This function sets the string setting provided with the value you passed.

If the value already existed, it gets overwritten.

pub fn set_setting_text(&mut self, key: &str, value: &str)

This function sets the text (multiline string) setting provided with the value you passed.

If the value already existed, it gets overwritten.

pub fn set_setting_bool(&mut self, key: &str, value: bool)

This function sets the bool setting provided with the value you passed.

If the value already existed, it gets overwritten.

pub fn set_setting_number(&mut self, key: &str, value: i32)

This function sets the numeric setting provided with the value you passed.

If the value already existed, it gets overwritten.

pub fn diagnostics_files_to_ignore( &self, ) -> Option<Vec<(String, Vec<String>, Vec<String>)>>

This function returns the list of paths which the diagnostic tool should ignore.

TODO: Move this to rpfm_extensions.