pub struct PortraitSettings { /* private fields */ }Expand description
Portrait settings file containing camera configurations for unit portraits.
Each entry in this file corresponds to an art set and defines how the camera should be positioned when rendering that unit’s portrait.
Implementations
Sourceimpl PortraitSettings
impl PortraitSettings
Sourcepub fn version_mut(&mut self) -> &mut u32
pub fn version_mut(&mut self) -> &mut u32
Format version of this file (1 or 4).
Sourcepub fn entries_mut(&mut self) -> &mut Vec<Entry>
pub fn entries_mut(&mut self) -> &mut Vec<Entry>
Portrait entries, one per art set.
Sourceimpl PortraitSettings
impl PortraitSettings
Sourcepub fn set_version(&mut self, val: u32) -> &mut Self
pub fn set_version(&mut self, val: u32) -> &mut Self
Format version of this file (1 or 4).
Sourcepub fn set_entries(&mut self, val: Vec<Entry>) -> &mut Self
pub fn set_entries(&mut self, val: Vec<Entry>) -> &mut Self
Portrait entries, one per art set.