Variant

Struct Variant 

pub struct Variant { /* private fields */ }
A texture variant for a portrait entry.

Variants allow different portrait textures to be used based on game conditions such as season, character level, age, or faction role.

Implementations

Source

impl Variant

pub fn filename(&self) -> &String

Variant identifier matching the variant_filename column in variants tables.

pub fn file_diffuse(&self) -> &String

Path to the diffuse (color) texture for this variant.

pub fn file_mask_1(&self) -> &String

Path to first mask texture (purpose unknown).

pub fn file_mask_2(&self) -> &String

Path to second mask texture (purpose unknown).

pub fn file_mask_3(&self) -> &String

Path to third mask texture (purpose unknown).

pub fn season(&self) -> &String

Season when this variant applies. Only used in version 1.

pub fn level(&self) -> &i32

Character level threshold. Only used in version 1.

pub fn age(&self) -> &i32

Character age threshold. Only used in version 1.

pub fn politician(&self) -> &bool

Whether this variant is for politicians. Only used in version 1.

pub fn faction_leader(&self) -> &bool

Whether this variant is for faction leaders. Only used in version 1.

Source

impl Variant

pub fn filename_mut(&mut self) -> &mut String

Variant identifier matching the variant_filename column in variants tables.

pub fn file_diffuse_mut(&mut self) -> &mut String

Path to the diffuse (color) texture for this variant.

pub fn file_mask_1_mut(&mut self) -> &mut String

Path to first mask texture (purpose unknown).

pub fn file_mask_2_mut(&mut self) -> &mut String

Path to second mask texture (purpose unknown).

pub fn file_mask_3_mut(&mut self) -> &mut String

Path to third mask texture (purpose unknown).

pub fn season_mut(&mut self) -> &mut String

Season when this variant applies. Only used in version 1.

pub fn level_mut(&mut self) -> &mut i32

Character level threshold. Only used in version 1.

pub fn age_mut(&mut self) -> &mut i32

Character age threshold. Only used in version 1.

pub fn politician_mut(&mut self) -> &mut bool

Whether this variant is for politicians. Only used in version 1.

pub fn faction_leader_mut(&mut self) -> &mut bool

Whether this variant is for faction leaders. Only used in version 1.

Source

impl Variant

pub fn set_filename(&mut self, val: String) -> &mut Self

Variant identifier matching the variant_filename column in variants tables.

pub fn set_file_diffuse(&mut self, val: String) -> &mut Self

Path to the diffuse (color) texture for this variant.

pub fn set_file_mask_1(&mut self, val: String) -> &mut Self

Path to first mask texture (purpose unknown).

pub fn set_file_mask_2(&mut self, val: String) -> &mut Self

Path to second mask texture (purpose unknown).

pub fn set_file_mask_3(&mut self, val: String) -> &mut Self

Path to third mask texture (purpose unknown).

pub fn set_season(&mut self, val: String) -> &mut Self

Season when this variant applies. Only used in version 1.

pub fn set_level(&mut self, val: i32) -> &mut Self

Character level threshold. Only used in version 1.

pub fn set_age(&mut self, val: i32) -> &mut Self

Character age threshold. Only used in version 1.

pub fn set_politician(&mut self, val: bool) -> &mut Self

Whether this variant is for politicians. Only used in version 1.

pub fn set_faction_leader(&mut self, val: bool) -> &mut Self

Whether this variant is for faction leaders. Only used in version 1.