pub struct BankEventProjectileFire { /* private fields */ }Expand description
Bank event for projectile firing sounds.
This is the only partially understood bank event type. It maps projectile firing actions to sound events based on weapon and projectile characteristics.
Implementations
Sourceimpl BankEventProjectileFire
impl BankEventProjectileFire
Sourcepub fn event_record_index(&self) -> &u32
pub fn event_record_index(&self) -> &u32
Index into the sound_events event_records array.
Sourcepub fn shot_types(&self) -> &Vec<u32>
pub fn shot_types(&self) -> &Vec<u32>
Shot type identifiers.
Sourcepub fn projectile_sizes(&self) -> &Vec<u32>
pub fn projectile_sizes(&self) -> &Vec<u32>
Projectile size categories.
Sourcepub fn unit_indexes(&self) -> &Vec<u32>
pub fn unit_indexes(&self) -> &Vec<u32>
Unit indices that use this sound.
Sourceimpl BankEventProjectileFire
impl BankEventProjectileFire
Sourcepub fn event_record_index_mut(&mut self) -> &mut u32
pub fn event_record_index_mut(&mut self) -> &mut u32
Index into the sound_events event_records array.
Sourcepub fn gun_types_mut(&mut self) -> &mut Vec<u32>
pub fn gun_types_mut(&mut self) -> &mut Vec<u32>
Gun type identifiers that trigger this sound.
Sourcepub fn shot_types_mut(&mut self) -> &mut Vec<u32>
pub fn shot_types_mut(&mut self) -> &mut Vec<u32>
Shot type identifiers.
Sourcepub fn projectile_sizes_mut(&mut self) -> &mut Vec<u32>
pub fn projectile_sizes_mut(&mut self) -> &mut Vec<u32>
Projectile size categories.
Sourcepub fn params_4_mut(&mut self) -> &mut Vec<u32>
pub fn params_4_mut(&mut self) -> &mut Vec<u32>
Unknown parameter set 4.
Sourcepub fn unit_indexes_mut(&mut self) -> &mut Vec<u32>
pub fn unit_indexes_mut(&mut self) -> &mut Vec<u32>
Unit indices that use this sound.
Sourceimpl BankEventProjectileFire
impl BankEventProjectileFire
Sourcepub fn set_event_record_index(&mut self, val: u32) -> &mut Self
pub fn set_event_record_index(&mut self, val: u32) -> &mut Self
Index into the sound_events event_records array.
Sourcepub fn set_gun_types(&mut self, val: Vec<u32>) -> &mut Self
pub fn set_gun_types(&mut self, val: Vec<u32>) -> &mut Self
Gun type identifiers that trigger this sound.
Sourcepub fn set_shot_types(&mut self, val: Vec<u32>) -> &mut Self
pub fn set_shot_types(&mut self, val: Vec<u32>) -> &mut Self
Shot type identifiers.
Sourcepub fn set_projectile_sizes(&mut self, val: Vec<u32>) -> &mut Self
pub fn set_projectile_sizes(&mut self, val: Vec<u32>) -> &mut Self
Projectile size categories.
Sourcepub fn set_params_4(&mut self, val: Vec<u32>) -> &mut Self
pub fn set_params_4(&mut self, val: Vec<u32>) -> &mut Self
Unknown parameter set 4.
Sourcepub fn set_unit_indexes(&mut self, val: Vec<u32>) -> &mut Self
pub fn set_unit_indexes(&mut self, val: Vec<u32>) -> &mut Self
Unit indices that use this sound.