EventData

Struct EventData 

pub struct EventData { /* private fields */ }
Event data parameters.

Contains a large set of float parameters that define audio playback characteristics. The exact meaning of each parameter is not fully understood.

Implementations

Source

impl EventData

pub fn uk_1(&self) -> &f32

Unknown parameter 1.

pub fn uk_2(&self) -> &f32

Unknown parameter 2.

pub fn uk_3(&self) -> &f32

Unknown parameter 3.

pub fn uk_4(&self) -> &f32

Unknown parameter 4.

pub fn uk_5(&self) -> &f32

Unknown parameter 5.

pub fn uk_6(&self) -> &f32

Unknown parameter 6.

pub fn uk_7(&self) -> &f32

Unknown parameter 7.

pub fn uk_8(&self) -> &f32

Unknown parameter 8.

pub fn uk_9(&self) -> &f32

Unknown parameter 9.

pub fn uk_10(&self) -> &f32

Unknown parameter 10.

pub fn uk_11(&self) -> &f32

Unknown parameter 11.

pub fn uk_12(&self) -> &f32

Unknown parameter 12.

pub fn uk_13(&self) -> &f32

Unknown parameter 13.

pub fn uk_14(&self) -> &f32

Unknown parameter 14.

pub fn uk_15(&self) -> &f32

Unknown parameter 15.

pub fn uk_16(&self) -> &f32

Unknown parameter 16.

pub fn uk_17(&self) -> &f32

Unknown parameter 17.

pub fn uk_18(&self) -> &f32

Unknown parameter 18.

pub fn uk_19(&self) -> &f32

Unknown parameter 19.

pub fn uk_20(&self) -> &f32

Unknown parameter 20.

pub fn uk_21(&self) -> &f32

Unknown parameter 21.

pub fn uk_22(&self) -> &f32

Unknown parameter 22.

pub fn uk_23(&self) -> &f32

Unknown parameter 23.

pub fn uk_24(&self) -> &f32

Unknown parameter 24.

pub fn uk_25(&self) -> &f32

Unknown parameter 25.

pub fn uk_26(&self) -> &f32

Unknown parameter 26.

pub fn uk_27(&self) -> &f32

Unknown parameter 27.

pub fn uk_28(&self) -> &f32

Unknown parameter 28.

pub fn uk_29(&self) -> &f32

Unknown parameter 29.

pub fn uk_30(&self) -> &f32

Unknown parameter 30.

pub fn uk_31(&self) -> &f32

Unknown parameter 31.

pub fn uk_32(&self) -> &f32

Unknown parameter 32.

pub fn uk_33(&self) -> &f32

Unknown parameter 33.

pub fn uk_34(&self) -> &f32

Unknown parameter 34.

pub fn uk_35(&self) -> &f32

Unknown parameter 35.

pub fn uk_36(&self) -> &f32

Unknown parameter 36.

pub fn uk_37(&self) -> &f32

Unknown parameter 37.

pub fn uk_38(&self) -> &f32

Unknown parameter 38.

pub fn uk_39(&self) -> &f32

Unknown parameter 39.

pub fn uk_40(&self) -> &f32

Unknown parameter 40.

pub fn uk_41(&self) -> &f32

Unknown parameter 41.

pub fn uk_42(&self) -> &f32

Unknown parameter 42.

pub fn uk_43(&self) -> &f32

Unknown parameter 43.

pub fn uk_44(&self) -> &f32

Unknown parameter 44.

pub fn uk_45(&self) -> &f32

Unknown parameter 45.

pub fn uk_46(&self) -> &f32

Unknown parameter 46.

pub fn uk_47(&self) -> &f32

Unknown parameter 47.

Source

impl EventData

pub fn uk_1_mut(&mut self) -> &mut f32

Unknown parameter 1.

pub fn uk_2_mut(&mut self) -> &mut f32

Unknown parameter 2.

pub fn uk_3_mut(&mut self) -> &mut f32

Unknown parameter 3.

pub fn uk_4_mut(&mut self) -> &mut f32

Unknown parameter 4.

pub fn uk_5_mut(&mut self) -> &mut f32

Unknown parameter 5.

pub fn uk_6_mut(&mut self) -> &mut f32

Unknown parameter 6.

pub fn uk_7_mut(&mut self) -> &mut f32

Unknown parameter 7.

pub fn uk_8_mut(&mut self) -> &mut f32

Unknown parameter 8.

pub fn uk_9_mut(&mut self) -> &mut f32

Unknown parameter 9.

pub fn uk_10_mut(&mut self) -> &mut f32

Unknown parameter 10.

pub fn uk_11_mut(&mut self) -> &mut f32

Unknown parameter 11.

pub fn uk_12_mut(&mut self) -> &mut f32

Unknown parameter 12.

pub fn uk_13_mut(&mut self) -> &mut f32

Unknown parameter 13.

pub fn uk_14_mut(&mut self) -> &mut f32

Unknown parameter 14.

pub fn uk_15_mut(&mut self) -> &mut f32

Unknown parameter 15.

pub fn uk_16_mut(&mut self) -> &mut f32

Unknown parameter 16.

pub fn uk_17_mut(&mut self) -> &mut f32

Unknown parameter 17.

pub fn uk_18_mut(&mut self) -> &mut f32

Unknown parameter 18.

pub fn uk_19_mut(&mut self) -> &mut f32

Unknown parameter 19.

pub fn uk_20_mut(&mut self) -> &mut f32

Unknown parameter 20.

pub fn uk_21_mut(&mut self) -> &mut f32

Unknown parameter 21.

pub fn uk_22_mut(&mut self) -> &mut f32

Unknown parameter 22.

pub fn uk_23_mut(&mut self) -> &mut f32

Unknown parameter 23.

pub fn uk_24_mut(&mut self) -> &mut f32

Unknown parameter 24.

pub fn uk_25_mut(&mut self) -> &mut f32

Unknown parameter 25.

pub fn uk_26_mut(&mut self) -> &mut f32

Unknown parameter 26.

pub fn uk_27_mut(&mut self) -> &mut f32

Unknown parameter 27.

pub fn uk_28_mut(&mut self) -> &mut f32

Unknown parameter 28.

pub fn uk_29_mut(&mut self) -> &mut f32

Unknown parameter 29.

pub fn uk_30_mut(&mut self) -> &mut f32

Unknown parameter 30.

pub fn uk_31_mut(&mut self) -> &mut f32

Unknown parameter 31.

pub fn uk_32_mut(&mut self) -> &mut f32

Unknown parameter 32.

pub fn uk_33_mut(&mut self) -> &mut f32

Unknown parameter 33.

pub fn uk_34_mut(&mut self) -> &mut f32

Unknown parameter 34.

pub fn uk_35_mut(&mut self) -> &mut f32

Unknown parameter 35.

pub fn uk_36_mut(&mut self) -> &mut f32

Unknown parameter 36.

pub fn uk_37_mut(&mut self) -> &mut f32

Unknown parameter 37.

pub fn uk_38_mut(&mut self) -> &mut f32

Unknown parameter 38.

pub fn uk_39_mut(&mut self) -> &mut f32

Unknown parameter 39.

pub fn uk_40_mut(&mut self) -> &mut f32

Unknown parameter 40.

pub fn uk_41_mut(&mut self) -> &mut f32

Unknown parameter 41.

pub fn uk_42_mut(&mut self) -> &mut f32

Unknown parameter 42.

pub fn uk_43_mut(&mut self) -> &mut f32

Unknown parameter 43.

pub fn uk_44_mut(&mut self) -> &mut f32

Unknown parameter 44.

pub fn uk_45_mut(&mut self) -> &mut f32

Unknown parameter 45.

pub fn uk_46_mut(&mut self) -> &mut f32

Unknown parameter 46.

pub fn uk_47_mut(&mut self) -> &mut f32

Unknown parameter 47.

Source

impl EventData

pub fn set_uk_1(&mut self, val: f32) -> &mut Self

Unknown parameter 1.

pub fn set_uk_2(&mut self, val: f32) -> &mut Self

Unknown parameter 2.

pub fn set_uk_3(&mut self, val: f32) -> &mut Self

Unknown parameter 3.

pub fn set_uk_4(&mut self, val: f32) -> &mut Self

Unknown parameter 4.

pub fn set_uk_5(&mut self, val: f32) -> &mut Self

Unknown parameter 5.

pub fn set_uk_6(&mut self, val: f32) -> &mut Self

Unknown parameter 6.

pub fn set_uk_7(&mut self, val: f32) -> &mut Self

Unknown parameter 7.

pub fn set_uk_8(&mut self, val: f32) -> &mut Self

Unknown parameter 8.

pub fn set_uk_9(&mut self, val: f32) -> &mut Self

Unknown parameter 9.

pub fn set_uk_10(&mut self, val: f32) -> &mut Self

Unknown parameter 10.

pub fn set_uk_11(&mut self, val: f32) -> &mut Self

Unknown parameter 11.

pub fn set_uk_12(&mut self, val: f32) -> &mut Self

Unknown parameter 12.

pub fn set_uk_13(&mut self, val: f32) -> &mut Self

Unknown parameter 13.

pub fn set_uk_14(&mut self, val: f32) -> &mut Self

Unknown parameter 14.

pub fn set_uk_15(&mut self, val: f32) -> &mut Self

Unknown parameter 15.

pub fn set_uk_16(&mut self, val: f32) -> &mut Self

Unknown parameter 16.

pub fn set_uk_17(&mut self, val: f32) -> &mut Self

Unknown parameter 17.

pub fn set_uk_18(&mut self, val: f32) -> &mut Self

Unknown parameter 18.

pub fn set_uk_19(&mut self, val: f32) -> &mut Self

Unknown parameter 19.

pub fn set_uk_20(&mut self, val: f32) -> &mut Self

Unknown parameter 20.

pub fn set_uk_21(&mut self, val: f32) -> &mut Self

Unknown parameter 21.

pub fn set_uk_22(&mut self, val: f32) -> &mut Self

Unknown parameter 22.

pub fn set_uk_23(&mut self, val: f32) -> &mut Self

Unknown parameter 23.

pub fn set_uk_24(&mut self, val: f32) -> &mut Self

Unknown parameter 24.

pub fn set_uk_25(&mut self, val: f32) -> &mut Self

Unknown parameter 25.

pub fn set_uk_26(&mut self, val: f32) -> &mut Self

Unknown parameter 26.

pub fn set_uk_27(&mut self, val: f32) -> &mut Self

Unknown parameter 27.

pub fn set_uk_28(&mut self, val: f32) -> &mut Self

Unknown parameter 28.

pub fn set_uk_29(&mut self, val: f32) -> &mut Self

Unknown parameter 29.

pub fn set_uk_30(&mut self, val: f32) -> &mut Self

Unknown parameter 30.

pub fn set_uk_31(&mut self, val: f32) -> &mut Self

Unknown parameter 31.

pub fn set_uk_32(&mut self, val: f32) -> &mut Self

Unknown parameter 32.

pub fn set_uk_33(&mut self, val: f32) -> &mut Self

Unknown parameter 33.

pub fn set_uk_34(&mut self, val: f32) -> &mut Self

Unknown parameter 34.

pub fn set_uk_35(&mut self, val: f32) -> &mut Self

Unknown parameter 35.

pub fn set_uk_36(&mut self, val: f32) -> &mut Self

Unknown parameter 36.

pub fn set_uk_37(&mut self, val: f32) -> &mut Self

Unknown parameter 37.

pub fn set_uk_38(&mut self, val: f32) -> &mut Self

Unknown parameter 38.

pub fn set_uk_39(&mut self, val: f32) -> &mut Self

Unknown parameter 39.

pub fn set_uk_40(&mut self, val: f32) -> &mut Self

Unknown parameter 40.

pub fn set_uk_41(&mut self, val: f32) -> &mut Self

Unknown parameter 41.

pub fn set_uk_42(&mut self, val: f32) -> &mut Self

Unknown parameter 42.

pub fn set_uk_43(&mut self, val: f32) -> &mut Self

Unknown parameter 43.

pub fn set_uk_44(&mut self, val: f32) -> &mut Self

Unknown parameter 44.

pub fn set_uk_45(&mut self, val: f32) -> &mut Self

Unknown parameter 45.

pub fn set_uk_46(&mut self, val: f32) -> &mut Self

Unknown parameter 46.

pub fn set_uk_47(&mut self, val: f32) -> &mut Self

Unknown parameter 47.