pub struct EventRecord { /* private fields */ }Expand description
A sound event record.
Defines a triggerable sound event that references sound files and event data parameters.
Implementations
Sourceimpl EventRecord
impl EventRecord
Sourcepub fn event_data_index(&self) -> &u32
pub fn event_data_index(&self) -> &u32
Index into the event_data array for this event’s parameters.
Sourceimpl EventRecord
impl EventRecord
Sourcepub fn category_mut(&mut self) -> &mut u32
pub fn category_mut(&mut self) -> &mut u32
Index of the category this event belongs to.
Sourcepub fn event_data_index_mut(&mut self) -> &mut u32
pub fn event_data_index_mut(&mut self) -> &mut u32
Index into the event_data array for this event’s parameters.
Sourcepub fn sounds_mut(&mut self) -> &mut Vec<String>
pub fn sounds_mut(&mut self) -> &mut Vec<String>
List of sound file paths associated with this event.
Sourceimpl EventRecord
impl EventRecord
Sourcepub fn set_category(&mut self, val: u32) -> &mut Self
pub fn set_category(&mut self, val: u32) -> &mut Self
Index of the category this event belongs to.
Sourcepub fn set_event_data_index(&mut self, val: u32) -> &mut Self
pub fn set_event_data_index(&mut self, val: u32) -> &mut Self
Index into the event_data array for this event’s parameters.
Sourcepub fn set_sounds(&mut self, val: Vec<String>) -> &mut Self
pub fn set_sounds(&mut self, val: Vec<String>) -> &mut Self
List of sound file paths associated with this event.