SoundEvents

Struct SoundEvents 

pub struct SoundEvents { /* private fields */ }
Sound events configuration for a game.

Contains the complete audio event system configuration including categories, event definitions, ambience mappings, and movie audio settings.

Note: Many fields in this format are not fully understood and are marked as uk_*.

Implementations

Source

impl SoundEvents

pub fn master_volume(&self) -> &f32

Master volume level for all sounds.

pub fn categories(&self) -> &Vec<Category>

Sound categories (e.g., music, SFX, voice).

pub fn uk_1(&self) -> &Vec<Uk1>

Unknown data section 1.

pub fn uk_4(&self) -> &Vec<Uk4>

Unknown data section 4.

pub fn uk_5(&self) -> &Vec<Uk5>

Unknown data section 5.

pub fn uk_6(&self) -> &u32

Unknown value 6.

pub fn uk_7(&self) -> &u32

Unknown value 7.

pub fn uk_8(&self) -> &Vec<Uk8>

Unknown data section 8.

pub fn event_data(&self) -> &Vec<EventData>

Event data parameters referenced by event records.

pub fn event_records(&self) -> &Vec<EventRecord>

Sound event definitions.

pub fn ambience_map(&self) -> &Vec<AmbienceMap>

Ambience sound mappings.

pub fn uk_3(&self) -> &Vec<Uk3>

Unknown data section 3.

pub fn movies(&self) -> &Vec<Movie>

Movie audio configurations.

pub fn uk_9(&self) -> &Vec<Uk9>

Unknown data section 9.

Source

impl SoundEvents

pub fn master_volume_mut(&mut self) -> &mut f32

Master volume level for all sounds.

pub fn categories_mut(&mut self) -> &mut Vec<Category>

Sound categories (e.g., music, SFX, voice).

pub fn uk_1_mut(&mut self) -> &mut Vec<Uk1>

Unknown data section 1.

pub fn uk_4_mut(&mut self) -> &mut Vec<Uk4>

Unknown data section 4.

pub fn uk_5_mut(&mut self) -> &mut Vec<Uk5>

Unknown data section 5.

pub fn uk_6_mut(&mut self) -> &mut u32

Unknown value 6.

pub fn uk_7_mut(&mut self) -> &mut u32

Unknown value 7.

pub fn uk_8_mut(&mut self) -> &mut Vec<Uk8>

Unknown data section 8.

pub fn event_data_mut(&mut self) -> &mut Vec<EventData>

Event data parameters referenced by event records.

pub fn event_records_mut(&mut self) -> &mut Vec<EventRecord>

Sound event definitions.

pub fn ambience_map_mut(&mut self) -> &mut Vec<AmbienceMap>

Ambience sound mappings.

pub fn uk_3_mut(&mut self) -> &mut Vec<Uk3>

Unknown data section 3.

pub fn movies_mut(&mut self) -> &mut Vec<Movie>

Movie audio configurations.

pub fn uk_9_mut(&mut self) -> &mut Vec<Uk9>

Unknown data section 9.

Source

impl SoundEvents

pub fn set_master_volume(&mut self, val: f32) -> &mut Self

Master volume level for all sounds.

pub fn set_categories(&mut self, val: Vec<Category>) -> &mut Self

Sound categories (e.g., music, SFX, voice).

pub fn set_uk_1(&mut self, val: Vec<Uk1>) -> &mut Self

Unknown data section 1.

pub fn set_uk_4(&mut self, val: Vec<Uk4>) -> &mut Self

Unknown data section 4.

pub fn set_uk_5(&mut self, val: Vec<Uk5>) -> &mut Self

Unknown data section 5.

pub fn set_uk_6(&mut self, val: u32) -> &mut Self

Unknown value 6.

pub fn set_uk_7(&mut self, val: u32) -> &mut Self

Unknown value 7.

pub fn set_uk_8(&mut self, val: Vec<Uk8>) -> &mut Self

Unknown data section 8.

pub fn set_event_data(&mut self, val: Vec<EventData>) -> &mut Self

Event data parameters referenced by event records.

pub fn set_event_records(&mut self, val: Vec<EventRecord>) -> &mut Self

Sound event definitions.

pub fn set_ambience_map(&mut self, val: Vec<AmbienceMap>) -> &mut Self

Ambience sound mappings.

pub fn set_uk_3(&mut self, val: Vec<Uk3>) -> &mut Self

Unknown data section 3.

pub fn set_movies(&mut self, val: Vec<Movie>) -> &mut Self

Movie audio configurations.

pub fn set_uk_9(&mut self, val: Vec<Uk9>) -> &mut Self

Unknown data section 9.