pub enum TextFormat {
Show 14 variants
Bat,
Cpp,
Html,
Hlsl,
Json,
Js,
Css,
Lua,
Markdown,
Plain,
Python,
Sql,
Xml,
Yaml,
}Expand description
File format types for syntax highlighting and validation.
Based on file extension, text files are classified into different formats. This allows text editors to apply appropriate syntax highlighting, code completion, and validation rules.
Format Detection
Format is determined by matching the file extension against the EXTENSIONS
table. If no match is found, defaults to TextFormat::Plain.
Variants
Bat
Windows batch script (.bat).
Cpp
C++ code or GLSL shaders (.cpp, .h, .glsl, .inl, .fx).
Html
HTML documents (.html, .htm).
Hlsl
HLSL shader code (.hlsl).
Json
JSON data files (.json, .code-snippets, .code-workspace).
Js
JavaScript code (.js).
Css
CSS stylesheets (.css).
Lua
Lua scripts (.lua, .twui, .battle_script).
Markdown
Markdown documentation (.md).
Plain
Plain text with no specific format (.txt, .csv, .tsv, .log, etc.).
Python
Python scripts (.py).
Sql
SQL queries (.sql).
Xml
XML configuration and data files (.xml, .kf*, .cindyscene, etc.).
Yaml
YAML configuration files (.yaml, .yml).