pub struct Video { /* private fields */ }Expand description
This represents an entire CaVp8 File decoded in memory.
Implementations
Sourceimpl Video
impl Video
Sourcepub fn format(&self) -> &SupportedFormats
pub fn format(&self) -> &SupportedFormats
Format of the video file
Sourcepub fn codec_four_cc(&self) -> &String
pub fn codec_four_cc(&self) -> &String
Codec FourCC (usually ‘VP80’).
Sourcepub fn num_frames(&self) -> &u32
pub fn num_frames(&self) -> &u32
Number of frames on the video.
Sourcepub fn extra_data(&self) -> &Option<(u8, u32, u32)>
pub fn extra_data(&self) -> &Option<(u8, u32, u32)>
Extra unknown data at the end of some headers.
Sourcepub fn frame_table(&self) -> &Vec<Frame>
pub fn frame_table(&self) -> &Vec<Frame>
Frame Table of the video.
Sourcepub fn frame_data(&self) -> &Vec<u8> ⓘ
pub fn frame_data(&self) -> &Vec<u8> ⓘ
Raw frame data of the video.
Sourceimpl Video
impl Video
Sourcepub fn set_format(&mut self, val: SupportedFormats) -> &mut Self
pub fn set_format(&mut self, val: SupportedFormats) -> &mut Self
Format of the video file
Sourcepub fn set_version(&mut self, val: u16) -> &mut Self
pub fn set_version(&mut self, val: u16) -> &mut Self
Version number.
Sourcepub fn set_codec_four_cc(&mut self, val: String) -> &mut Self
pub fn set_codec_four_cc(&mut self, val: String) -> &mut Self
Codec FourCC (usually ‘VP80’).
Sourcepub fn set_height(&mut self, val: u16) -> &mut Self
pub fn set_height(&mut self, val: u16) -> &mut Self
Height of the video in pixels.
Sourcepub fn set_num_frames(&mut self, val: u32) -> &mut Self
pub fn set_num_frames(&mut self, val: u32) -> &mut Self
Number of frames on the video.
Sourcepub fn set_framerate(&mut self, val: f32) -> &mut Self
pub fn set_framerate(&mut self, val: f32) -> &mut Self
Framerate of the video.
Sourcepub fn set_extra_data(&mut self, val: Option<(u8, u32, u32)>) -> &mut Self
pub fn set_extra_data(&mut self, val: Option<(u8, u32, u32)>) -> &mut Self
Extra unknown data at the end of some headers.
Sourcepub fn set_frame_table(&mut self, val: Vec<Frame>) -> &mut Self
pub fn set_frame_table(&mut self, val: Vec<Frame>) -> &mut Self
Frame Table of the video.
Sourcepub fn set_frame_data(&mut self, val: Vec<u8>) -> &mut Self
pub fn set_frame_data(&mut self, val: Vec<u8>) -> &mut Self
Raw frame data of the video.