files_in_folder_from_newest_to_oldest

Function files_in_folder_from_newest_to_oldest 

pub fn files_in_folder_from_newest_to_oldest(
    current_path: &Path,
) -> Result<Vec<PathBuf>>
Returns all files in a directory sorted by modification time (newest first).

Arguments

  • current_path - The directory to search (non-recursive)

Returns

Returns a vector of file paths sorted from newest to oldest by modification time.