last_modified_time_from_file

Function last_modified_time_from_file 

pub fn last_modified_time_from_file(file: &File) -> Result<u64>
Returns the last modification time of a file as a Unix timestamp.

Arguments

  • file - The file handle to query

Returns

Returns the number of seconds since the Unix epoch when the file was last modified.