pub struct Audio { /* private fields */ }Expand description
Container for raw audio file data.
Stores audio data in its original binary format without decoding. This allows audio files to be extracted, modified with external tools, and re-packed.
Fields
data- Raw binary audio data (MP3, WEM, or WAV format)
Getters
Fields have public getters via the getset crate:
data()- Get reference to the raw audio bytes
Example
use rpfm_lib::files::{Decodeable, Encodeable, audio::Audio};
use std::io::Cursor;
let mut reader = Cursor::new(mp3_data.clone());
let audio = Audio::decode(&mut reader, &None).unwrap();
assert_eq!(audio.data(), &mp3_data);Implementations