pub struct BuildingLink { /* private fields */ }Expand description
Links a building instance to a prefab instance.
Building links establish relationships between buildings in the battlefield building list and their associated prefab instances. This allows buildings to reference prefab data for models, textures, and other assets.
Fields
serialise_version: Format version (1-3)building_index: Index of the building in the building listprefab_index: Index of the prefab in the prefab listprefab_building_key: String key identifying the prefab buildinguid: Unique identifier for this building linkprefab_uid: Unique identifier of the associated prefabbuilding_reference: Reference data for the building
Example
use rpfm_lib::files::bmd::common::building_link::BuildingLink;
let mut link = BuildingLink::default();
link.set_serialise_version(3);
link.set_building_index(5);
link.set_prefab_building_key("settlement_wall_01".to_string());Implementations
Sourceimpl BuildingLink
impl BuildingLink
Sourcepub fn serialise_version(&self) -> &u16
pub fn serialise_version(&self) -> &u16
Format version number (1-3).
Sourcepub fn building_index(&self) -> &i32
pub fn building_index(&self) -> &i32
Index of the building in the building list.
Sourcepub fn prefab_index(&self) -> &i32
pub fn prefab_index(&self) -> &i32
Index of the prefab in the prefab list.
Sourcepub fn prefab_building_key(&self) -> &String
pub fn prefab_building_key(&self) -> &String
String key identifying the prefab building.
Sourcepub fn prefab_uid(&self) -> &u64
pub fn prefab_uid(&self) -> &u64
Unique identifier of the associated prefab.
Sourcepub fn building_reference(&self) -> &BuildingReference
pub fn building_reference(&self) -> &BuildingReference
Reference data for the building.
Sourceimpl BuildingLink
impl BuildingLink
Sourcepub fn serialise_version_mut(&mut self) -> &mut u16
pub fn serialise_version_mut(&mut self) -> &mut u16
Format version number (1-3).
Sourcepub fn building_index_mut(&mut self) -> &mut i32
pub fn building_index_mut(&mut self) -> &mut i32
Index of the building in the building list.
Sourcepub fn prefab_index_mut(&mut self) -> &mut i32
pub fn prefab_index_mut(&mut self) -> &mut i32
Index of the prefab in the prefab list.
Sourcepub fn prefab_building_key_mut(&mut self) -> &mut String
pub fn prefab_building_key_mut(&mut self) -> &mut String
String key identifying the prefab building.
Sourcepub fn prefab_uid_mut(&mut self) -> &mut u64
pub fn prefab_uid_mut(&mut self) -> &mut u64
Unique identifier of the associated prefab.
Sourcepub fn building_reference_mut(&mut self) -> &mut BuildingReference
pub fn building_reference_mut(&mut self) -> &mut BuildingReference
Reference data for the building.
Sourceimpl BuildingLink
impl BuildingLink
Sourcepub fn set_serialise_version(&mut self, val: u16) -> &mut Self
pub fn set_serialise_version(&mut self, val: u16) -> &mut Self
Format version number (1-3).
Sourcepub fn set_building_index(&mut self, val: i32) -> &mut Self
pub fn set_building_index(&mut self, val: i32) -> &mut Self
Index of the building in the building list.
Sourcepub fn set_prefab_index(&mut self, val: i32) -> &mut Self
pub fn set_prefab_index(&mut self, val: i32) -> &mut Self
Index of the prefab in the prefab list.
Sourcepub fn set_prefab_building_key(&mut self, val: String) -> &mut Self
pub fn set_prefab_building_key(&mut self, val: String) -> &mut Self
String key identifying the prefab building.
Sourcepub fn set_prefab_uid(&mut self, val: u64) -> &mut Self
pub fn set_prefab_uid(&mut self, val: u64) -> &mut Self
Unique identifier of the associated prefab.
Sourcepub fn set_building_reference(&mut self, val: BuildingReference) -> &mut Self
pub fn set_building_reference(&mut self, val: BuildingReference) -> &mut Self
Reference data for the building.