pub struct RecordNodeFlags(/* private fields */);Expand description
Flags that control how a record node is encoded in the ESF binary format.
These flags are stored in the high bits of the type byte for record nodes. The combination of flags determines how the node header and children are encoded.
Binary Layout
For a record node’s first byte:
- Bit 7 (0x80): Always set for record nodes (
IS_RECORD_NODE) - Bit 6 (0x40): Set if node has nested blocks (
HAS_NESTED_BLOCKS) - Bit 5 (0x20): Set if using non-optimized header format (
HAS_NON_OPTIMIZED_INFO) - Bits 0-4: Used for optimized encoding of version/name when bit 5 is clear
Implementations
Sourceimpl RecordNodeFlags
impl RecordNodeFlags
Sourcepub const IS_RECORD_NODE: Self
pub const IS_RECORD_NODE: Self
Indicates this is a record node (container with children). This flag is always set for record nodes and distinguishes them from primitive nodes.
Sourcepub const HAS_NESTED_BLOCKS: Self
pub const HAS_NESTED_BLOCKS: Self
Indicates the record contains multiple groups of children (nested blocks). When set, children are organized into separate groups, each with its own size prefix. When clear, all children are in a single flat list.
Sourcepub const HAS_NON_OPTIMIZED_INFO: Self
pub const HAS_NON_OPTIMIZED_INFO: Self
Indicates the node uses the full 3-byte header format (u16 name index + u8 version). When clear, the header is compressed into 2 bytes using bitwise encoding:
- Bits 1-4: Version (4 bits, max 15)
- Bit 0 + next byte: Name index (9 bits, max 511)
Sourceimpl RecordNodeFlags
impl RecordNodeFlags
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl RecordNodeFlags
impl RecordNodeFlags
Sourcepub const fn iter(&self) -> Iter<RecordNodeFlags>
pub const fn iter(&self) -> Iter<RecordNodeFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RecordNodeFlags>
pub const fn iter_names(&self) -> IterNames<RecordNodeFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.