pub struct CUFProperties { /* private fields */ }Expand description
Font properties controlling text layout and rendering.
Many of these properties are indices or references whose exact purpose is still being researched. Comments from the Europa Barbarorum Team’s research have been preserved for reference.
Implementations
Sourceimpl CUFProperties
impl CUFProperties
Sourcepub fn first_prop(&self) -> &u16
pub fn first_prop(&self) -> &u16
Unknown purpose (first CUF property).
Sourcepub fn second_prop(&self) -> &u16
pub fn second_prop(&self) -> &u16
Unknown purpose. Second CUF property.
Sourcepub fn line_height(&self) -> &u16
pub fn line_height(&self) -> &u16
Index of the value which appears to have something to do with line height. Underscore line? Base line?
Sourcepub fn fourth_prop(&self) -> &u16
pub fn fourth_prop(&self) -> &u16
Unknown purpose. Fourth CUF property.
Sourcepub fn fifth_prop(&self) -> &u16
pub fn fifth_prop(&self) -> &u16
Unknown purpose. Fifth CUF property.
Sourcepub fn baseline(&self) -> &u16
pub fn baseline(&self) -> &u16
Index of the value which appears to correspond to a ‘baseline’ of sorts in the CUF file format.
Sourcepub fn layout_y_offset(&self) -> &u16
pub fn layout_y_offset(&self) -> &u16
Index of the value which determines y-offset w.r.t. the bounding box of a string of text in this font.
Sourcepub fn space_justify(&self) -> &u16
pub fn space_justify(&self) -> &u16
Used to specify how wide a space is for justification and text wrapping calculations.
Sourcepub fn layout_x_offset(&self) -> &u16
pub fn layout_x_offset(&self) -> &u16
Index of the value which determines x-offset w.r.t. the bounding box of a string of text in this font.
Sourcepub fn h_size(&self) -> &u16
pub fn h_size(&self) -> &u16
Index of the value which determines a maximum width for glyphs. Glyphs which are wider than the maximum specified for this property will appear cut-off.
There appears to be no effect on the position of a glyph after a glyph of which the advance is larger than the value specified for this setting.
Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.
Sourcepub fn v_size(&self) -> &u16
pub fn v_size(&self) -> &u16
Index of the value which determines a maximum height for glyphs. The corresponding value probably should include leading. Glyphs which are taller than the maximum specified for this property will appear cut-off.
Too small values for this property may result in crashes or unspecified errors on exit in M2TW.
Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.
Sourceimpl CUFProperties
impl CUFProperties
Sourcepub fn first_prop_mut(&mut self) -> &mut u16
pub fn first_prop_mut(&mut self) -> &mut u16
Unknown purpose (first CUF property).
Sourcepub fn second_prop_mut(&mut self) -> &mut u16
pub fn second_prop_mut(&mut self) -> &mut u16
Unknown purpose. Second CUF property.
Sourcepub fn line_height_mut(&mut self) -> &mut u16
pub fn line_height_mut(&mut self) -> &mut u16
Index of the value which appears to have something to do with line height. Underscore line? Base line?
Sourcepub fn fourth_prop_mut(&mut self) -> &mut u16
pub fn fourth_prop_mut(&mut self) -> &mut u16
Unknown purpose. Fourth CUF property.
Sourcepub fn fifth_prop_mut(&mut self) -> &mut u16
pub fn fifth_prop_mut(&mut self) -> &mut u16
Unknown purpose. Fifth CUF property.
Sourcepub fn baseline_mut(&mut self) -> &mut u16
pub fn baseline_mut(&mut self) -> &mut u16
Index of the value which appears to correspond to a ‘baseline’ of sorts in the CUF file format.
Sourcepub fn layout_y_offset_mut(&mut self) -> &mut u16
pub fn layout_y_offset_mut(&mut self) -> &mut u16
Index of the value which determines y-offset w.r.t. the bounding box of a string of text in this font.
Sourcepub fn space_justify_mut(&mut self) -> &mut u16
pub fn space_justify_mut(&mut self) -> &mut u16
Used to specify how wide a space is for justification and text wrapping calculations.
Sourcepub fn layout_x_offset_mut(&mut self) -> &mut u16
pub fn layout_x_offset_mut(&mut self) -> &mut u16
Index of the value which determines x-offset w.r.t. the bounding box of a string of text in this font.
Sourcepub fn h_size_mut(&mut self) -> &mut u16
pub fn h_size_mut(&mut self) -> &mut u16
Index of the value which determines a maximum width for glyphs. Glyphs which are wider than the maximum specified for this property will appear cut-off.
There appears to be no effect on the position of a glyph after a glyph of which the advance is larger than the value specified for this setting.
Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.
Sourcepub fn v_size_mut(&mut self) -> &mut u16
pub fn v_size_mut(&mut self) -> &mut u16
Index of the value which determines a maximum height for glyphs. The corresponding value probably should include leading. Glyphs which are taller than the maximum specified for this property will appear cut-off.
Too small values for this property may result in crashes or unspecified errors on exit in M2TW.
Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.
Sourceimpl CUFProperties
impl CUFProperties
Sourcepub fn set_first_prop(&mut self, val: u16) -> &mut Self
pub fn set_first_prop(&mut self, val: u16) -> &mut Self
Unknown purpose (first CUF property).
Sourcepub fn set_second_prop(&mut self, val: u16) -> &mut Self
pub fn set_second_prop(&mut self, val: u16) -> &mut Self
Unknown purpose. Second CUF property.
Sourcepub fn set_line_height(&mut self, val: u16) -> &mut Self
pub fn set_line_height(&mut self, val: u16) -> &mut Self
Index of the value which appears to have something to do with line height. Underscore line? Base line?
Sourcepub fn set_fourth_prop(&mut self, val: u16) -> &mut Self
pub fn set_fourth_prop(&mut self, val: u16) -> &mut Self
Unknown purpose. Fourth CUF property.
Sourcepub fn set_fifth_prop(&mut self, val: u16) -> &mut Self
pub fn set_fifth_prop(&mut self, val: u16) -> &mut Self
Unknown purpose. Fifth CUF property.
Sourcepub fn set_baseline(&mut self, val: u16) -> &mut Self
pub fn set_baseline(&mut self, val: u16) -> &mut Self
Index of the value which appears to correspond to a ‘baseline’ of sorts in the CUF file format.
Sourcepub fn set_layout_y_offset(&mut self, val: u16) -> &mut Self
pub fn set_layout_y_offset(&mut self, val: u16) -> &mut Self
Index of the value which determines y-offset w.r.t. the bounding box of a string of text in this font.
Sourcepub fn set_space_justify(&mut self, val: u16) -> &mut Self
pub fn set_space_justify(&mut self, val: u16) -> &mut Self
Used to specify how wide a space is for justification and text wrapping calculations.
Sourcepub fn set_layout_x_offset(&mut self, val: u16) -> &mut Self
pub fn set_layout_x_offset(&mut self, val: u16) -> &mut Self
Index of the value which determines x-offset w.r.t. the bounding box of a string of text in this font.
Sourcepub fn set_h_size(&mut self, val: u16) -> &mut Self
pub fn set_h_size(&mut self, val: u16) -> &mut Self
Index of the value which determines a maximum width for glyphs. Glyphs which are wider than the maximum specified for this property will appear cut-off.
There appears to be no effect on the position of a glyph after a glyph of which the advance is larger than the value specified for this setting.
Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.
Sourcepub fn set_v_size(&mut self, val: u16) -> &mut Self
pub fn set_v_size(&mut self, val: u16) -> &mut Self
Index of the value which determines a maximum height for glyphs. The corresponding value probably should include leading. Glyphs which are taller than the maximum specified for this property will appear cut-off.
Too small values for this property may result in crashes or unspecified errors on exit in M2TW.
Note that individual glyphs contain sufficient information to calculate a much more optimal bounding box than by simply using multiples of the value corresponding to this index.