pub struct ContainerAbsolute { /* private fields */ }Expand description
A container block positioned at absolute coordinates on the battlefield.
Defines how units should be arranged at a specific location, including their spacing, arrangement pattern, and which types of units should occupy this position.
Implementations
Sourceimpl ContainerAbsolute
impl ContainerAbsolute
Sourcepub fn block_priority(&self) -> &f32
pub fn block_priority(&self) -> &f32
Priority for filling this block (higher priority blocks are filled first).
Sourcepub fn entity_arrangement(&self) -> &EntityArrangement
pub fn entity_arrangement(&self) -> &EntityArrangement
How units should be arranged (line, column, crescent, etc.).
Sourcepub fn inter_entity_spacing(&self) -> &f32
pub fn inter_entity_spacing(&self) -> &f32
Spacing between units in this block.
Sourcepub fn crescent_y_offset(&self) -> &f32
pub fn crescent_y_offset(&self) -> &f32
Y-axis offset for crescent formations.
Sourcepub fn position_x(&self) -> &f32
pub fn position_x(&self) -> &f32
X coordinate of this block’s position.
Sourcepub fn position_y(&self) -> &f32
pub fn position_y(&self) -> &f32
Y coordinate of this block’s position.
Sourcepub fn minimum_entity_threshold(&self) -> &i32
pub fn minimum_entity_threshold(&self) -> &i32
Minimum number of units required to use this block.
Sourcepub fn maximum_entity_threshold(&self) -> &i32
pub fn maximum_entity_threshold(&self) -> &i32
Maximum number of units that can be placed in this block.
Sourcepub fn entity_preferences(&self) -> &Vec<EntityPreference>
pub fn entity_preferences(&self) -> &Vec<EntityPreference>
Ordered list of preferred unit types for this block.
Sourceimpl ContainerAbsolute
impl ContainerAbsolute
Sourcepub fn block_priority_mut(&mut self) -> &mut f32
pub fn block_priority_mut(&mut self) -> &mut f32
Priority for filling this block (higher priority blocks are filled first).
Sourcepub fn entity_arrangement_mut(&mut self) -> &mut EntityArrangement
pub fn entity_arrangement_mut(&mut self) -> &mut EntityArrangement
How units should be arranged (line, column, crescent, etc.).
Sourcepub fn inter_entity_spacing_mut(&mut self) -> &mut f32
pub fn inter_entity_spacing_mut(&mut self) -> &mut f32
Spacing between units in this block.
Sourcepub fn crescent_y_offset_mut(&mut self) -> &mut f32
pub fn crescent_y_offset_mut(&mut self) -> &mut f32
Y-axis offset for crescent formations.
Sourcepub fn position_x_mut(&mut self) -> &mut f32
pub fn position_x_mut(&mut self) -> &mut f32
X coordinate of this block’s position.
Sourcepub fn position_y_mut(&mut self) -> &mut f32
pub fn position_y_mut(&mut self) -> &mut f32
Y coordinate of this block’s position.
Sourcepub fn minimum_entity_threshold_mut(&mut self) -> &mut i32
pub fn minimum_entity_threshold_mut(&mut self) -> &mut i32
Minimum number of units required to use this block.
Sourcepub fn maximum_entity_threshold_mut(&mut self) -> &mut i32
pub fn maximum_entity_threshold_mut(&mut self) -> &mut i32
Maximum number of units that can be placed in this block.
Sourcepub fn entity_preferences_mut(&mut self) -> &mut Vec<EntityPreference>
pub fn entity_preferences_mut(&mut self) -> &mut Vec<EntityPreference>
Ordered list of preferred unit types for this block.
Sourceimpl ContainerAbsolute
impl ContainerAbsolute
Sourcepub fn set_block_priority(&mut self, val: f32) -> &mut Self
pub fn set_block_priority(&mut self, val: f32) -> &mut Self
Priority for filling this block (higher priority blocks are filled first).
Sourcepub fn set_entity_arrangement(&mut self, val: EntityArrangement) -> &mut Self
pub fn set_entity_arrangement(&mut self, val: EntityArrangement) -> &mut Self
How units should be arranged (line, column, crescent, etc.).
Sourcepub fn set_inter_entity_spacing(&mut self, val: f32) -> &mut Self
pub fn set_inter_entity_spacing(&mut self, val: f32) -> &mut Self
Spacing between units in this block.
Sourcepub fn set_crescent_y_offset(&mut self, val: f32) -> &mut Self
pub fn set_crescent_y_offset(&mut self, val: f32) -> &mut Self
Y-axis offset for crescent formations.
Sourcepub fn set_position_x(&mut self, val: f32) -> &mut Self
pub fn set_position_x(&mut self, val: f32) -> &mut Self
X coordinate of this block’s position.
Sourcepub fn set_position_y(&mut self, val: f32) -> &mut Self
pub fn set_position_y(&mut self, val: f32) -> &mut Self
Y coordinate of this block’s position.
Sourcepub fn set_minimum_entity_threshold(&mut self, val: i32) -> &mut Self
pub fn set_minimum_entity_threshold(&mut self, val: i32) -> &mut Self
Minimum number of units required to use this block.
Sourcepub fn set_maximum_entity_threshold(&mut self, val: i32) -> &mut Self
pub fn set_maximum_entity_threshold(&mut self, val: i32) -> &mut Self
Maximum number of units that can be placed in this block.
Sourcepub fn set_entity_preferences(
&mut self,
val: Vec<EntityPreference>,
) -> &mut Self
pub fn set_entity_preferences( &mut self, val: Vec<EntityPreference>, ) -> &mut Self
Ordered list of preferred unit types for this block.