pub struct EntityPreference { /* private fields */ }Expand description
Defines a preference for a specific type of unit to occupy a formation block.
Multiple preferences can be defined in priority order, so the AI will try to place the highest priority matching units first.
Implementations
Sourceimpl EntityPreference
impl EntityPreference
Sourcepub fn entity(&self) -> &Entity
pub fn entity(&self) -> &Entity
The type of unit entity (infantry, cavalry, artillery, etc.).
Note: This is called EntityClass in Rome 2 and EntityDescription in Shogun 2, but represents the same concept.
Sourcepub fn entity_weight(&self) -> &EntityWeight
pub fn entity_weight(&self) -> &EntityWeight
Weight class of the unit (light, medium, heavy, etc.). Introduced in Rome 2.
Sourcepub fn entity_class(&self) -> &String
pub fn entity_class(&self) -> &String
Entity class string identifier (used in Three Kingdoms).
Sourceimpl EntityPreference
impl EntityPreference
Sourcepub fn priority_mut(&mut self) -> &mut f32
pub fn priority_mut(&mut self) -> &mut f32
Priority for this entity type (higher = more preferred).
Sourcepub fn entity_mut(&mut self) -> &mut Entity
pub fn entity_mut(&mut self) -> &mut Entity
The type of unit entity (infantry, cavalry, artillery, etc.).
Note: This is called EntityClass in Rome 2 and EntityDescription in Shogun 2, but represents the same concept.
Sourcepub fn entity_weight_mut(&mut self) -> &mut EntityWeight
pub fn entity_weight_mut(&mut self) -> &mut EntityWeight
Weight class of the unit (light, medium, heavy, etc.). Introduced in Rome 2.
Sourcepub fn entity_class_mut(&mut self) -> &mut String
pub fn entity_class_mut(&mut self) -> &mut String
Entity class string identifier (used in Three Kingdoms).
Sourceimpl EntityPreference
impl EntityPreference
Sourcepub fn set_priority(&mut self, val: f32) -> &mut Self
pub fn set_priority(&mut self, val: f32) -> &mut Self
Priority for this entity type (higher = more preferred).
Sourcepub fn set_entity(&mut self, val: Entity) -> &mut Self
pub fn set_entity(&mut self, val: Entity) -> &mut Self
The type of unit entity (infantry, cavalry, artillery, etc.).
Note: This is called EntityClass in Rome 2 and EntityDescription in Shogun 2, but represents the same concept.
Sourcepub fn set_entity_weight(&mut self, val: EntityWeight) -> &mut Self
pub fn set_entity_weight(&mut self, val: EntityWeight) -> &mut Self
Weight class of the unit (light, medium, heavy, etc.). Introduced in Rome 2.
Sourcepub fn set_entity_class(&mut self, val: String) -> &mut Self
pub fn set_entity_class(&mut self, val: String) -> &mut Self
Entity class string identifier (used in Three Kingdoms).