pub struct EntityBundle { /* private fields */ }Expand description
A bundle of animation entities that can be selected together.
Allows the game to randomly choose between different animation variations based on selection weights, providing visual variety in combat.
Implementations
Sourceimpl EntityBundle
impl EntityBundle
Sourceimpl EntityBundle
impl EntityBundle
Sourcepub fn set_entities(&mut self, val: Vec<Entity>) -> &mut Self
pub fn set_entities(&mut self, val: Vec<Entity>) -> &mut Self
Animation entities in this bundle.
Sourcepub fn set_selection_weight(&mut self, val: f32) -> &mut Self
pub fn set_selection_weight(&mut self, val: f32) -> &mut Self
Weight for random selection of this bundle (higher = more likely to be chosen).