pub struct PackHeader { /* private fields */ }Expand description
Header of a Pack, containing all the header-related info of said Pack.
Header Structure.
| Bytes | Type | Data |
|---|---|---|
| 8 | 00-Padded StringU8 | Fake Preamble/Id of this Pack. Usually “MFH” and a bunch of 00. Only in old Steam Workshop files. |
| 4 | StringU8 | Preamble/Id of this Pack. Contains the “version” of this Pack. |
| 4 | u32 | Pack Type + Bitwised flags for tweaking certain Pack configurations. |
| 4 | u32 | Amount of items in the Pack Index of this Pack. |
| 4 | u32 | Lenght in bytes of the Pack Index. |
| 4 | u32 | Amount of items in the File Index of this Pack. |
| 4 | u32 | Lenght in bytes of the File Index. |
| 8 | u64 | Timestamp when this Pack was last edited. Only in PFH2 and PFH3. |
| 20 | Vec<u8> | Extended header data. Only if HAS_EXTENDED_HEADER flag is set. |
| 280 | Subheader | Subheader data. Only since PFH6. |
Subheader Structure.
Subheader containing extra metadata for the Pack. Only in PFH6.
| Bytes | Type | Data |
|---|---|---|
| 4 | u32 | Subheader marker. Marks the begining of the subheader. If missing, there’s no subheader. |
| 4 | u32 | Subheader version. |
| 4 | u32 | Game version this Pack was done for. |
| 4 | u32 | Build number of the game version this Pack was done for. |
| 8 | 00-Padded StringU8 | Tool that made this Pack. |
| 256 | Vec<u8> | Unused bytes. |
Implementations
Sourceimpl PackHeader
impl PackHeader
Sourcepub fn pfh_version(&self) -> &PFHVersion
pub fn pfh_version(&self) -> &PFHVersion
The version of the Pack.
Sourcepub fn pfh_file_type(&self) -> &PFHFileType
pub fn pfh_file_type(&self) -> &PFHFileType
The type of the Pack.
Sourcepub fn internal_timestamp(&self) -> &u64
pub fn internal_timestamp(&self) -> &u64
The timestamp of the last time the Pack was saved.
Sourcepub fn game_version(&self) -> &u32
pub fn game_version(&self) -> &u32
Game version this Pack is intended for. This usually triggers the “outdated mod” warning in the launcher if it doesn’t match the current exe version.
Sourcepub fn build_number(&self) -> &u32
pub fn build_number(&self) -> &u32
Build number of the game.
Tool that created the Pack. Max 8 characters, 00-padded.
Sourcepub fn extra_subheader_data(&self) -> &Vec<u8> ⓘ
pub fn extra_subheader_data(&self) -> &Vec<u8> ⓘ
Extra subheader data, in case it’s used in the future.
Sourceimpl PackHeader
impl PackHeader
Sourcepub fn set_pfh_version(&mut self, val: PFHVersion) -> &mut Self
pub fn set_pfh_version(&mut self, val: PFHVersion) -> &mut Self
The version of the Pack.
Sourcepub fn set_pfh_file_type(&mut self, val: PFHFileType) -> &mut Self
pub fn set_pfh_file_type(&mut self, val: PFHFileType) -> &mut Self
The type of the Pack.
Sourcepub fn set_bitmask(&mut self, val: PFHFlags) -> &mut Self
pub fn set_bitmask(&mut self, val: PFHFlags) -> &mut Self
The bitmasks applied to the Pack.
Sourcepub fn set_internal_timestamp(&mut self, val: u64) -> &mut Self
pub fn set_internal_timestamp(&mut self, val: u64) -> &mut Self
The timestamp of the last time the Pack was saved.
Sourcepub fn set_game_version(&mut self, val: u32) -> &mut Self
pub fn set_game_version(&mut self, val: u32) -> &mut Self
Game version this Pack is intended for. This usually triggers the “outdated mod” warning in the launcher if it doesn’t match the current exe version.
Sourcepub fn set_build_number(&mut self, val: u32) -> &mut Self
pub fn set_build_number(&mut self, val: u32) -> &mut Self
Build number of the game.
Tool that created the Pack. Max 8 characters, 00-padded.
Sourcepub fn set_extra_subheader_data(&mut self, val: Vec<u8>) -> &mut Self
pub fn set_extra_subheader_data(&mut self, val: Vec<u8>) -> &mut Self
Extra subheader data, in case it’s used in the future.