pub struct PackSettings { /* private fields */ }Expand description
Pack-specific settings stored within the pack itself.
These settings are serialized to a reserved file within the pack, allowing them to be shared when the pack is distributed. Common settings include compression format, diagnostic ignore lists, and import configurations.
Built-in Settings
compression_format: The compression format to use (None, Lz4, Zlib)diagnostics_files_to_ignore: Files/diagnostics to skip during validationimport_files_to_ignore: Files to skip during folder importsdisable_autosaves: Disable automatic savingdo_not_generate_existing_locs: Skip generating loc entries that already exist
Implementations
Sourceimpl PackSettings
impl PackSettings
Sourcepub fn settings_text(&self) -> &BTreeMap<String, String>
pub fn settings_text(&self) -> &BTreeMap<String, String>
Multi-line text settings (e.g., file ignore lists).
Sourcepub fn settings_string(&self) -> &BTreeMap<String, String>
pub fn settings_string(&self) -> &BTreeMap<String, String>
Single-line string settings (e.g., compression format).
Sourcepub fn settings_bool(&self) -> &BTreeMap<String, bool>
pub fn settings_bool(&self) -> &BTreeMap<String, bool>
Boolean flag settings (e.g., disable_autosaves).
Sourcepub fn settings_number(&self) -> &BTreeMap<String, i32>
pub fn settings_number(&self) -> &BTreeMap<String, i32>
Integer settings (e.g., thresholds, limits).
Sourceimpl PackSettings
impl PackSettings
Sourcepub fn settings_text_mut(&mut self) -> &mut BTreeMap<String, String>
pub fn settings_text_mut(&mut self) -> &mut BTreeMap<String, String>
Multi-line text settings (e.g., file ignore lists).
Sourcepub fn settings_string_mut(&mut self) -> &mut BTreeMap<String, String>
pub fn settings_string_mut(&mut self) -> &mut BTreeMap<String, String>
Single-line string settings (e.g., compression format).
Sourcepub fn settings_bool_mut(&mut self) -> &mut BTreeMap<String, bool>
pub fn settings_bool_mut(&mut self) -> &mut BTreeMap<String, bool>
Boolean flag settings (e.g., disable_autosaves).
Sourcepub fn settings_number_mut(&mut self) -> &mut BTreeMap<String, i32>
pub fn settings_number_mut(&mut self) -> &mut BTreeMap<String, i32>
Integer settings (e.g., thresholds, limits).
Sourceimpl PackSettings
impl PackSettings
Sourcepub fn set_settings_text(&mut self, val: BTreeMap<String, String>) -> &mut Self
pub fn set_settings_text(&mut self, val: BTreeMap<String, String>) -> &mut Self
Multi-line text settings (e.g., file ignore lists).
Sourcepub fn set_settings_string(
&mut self,
val: BTreeMap<String, String>,
) -> &mut Self
pub fn set_settings_string( &mut self, val: BTreeMap<String, String>, ) -> &mut Self
Single-line string settings (e.g., compression format).
Sourcepub fn set_settings_bool(&mut self, val: BTreeMap<String, bool>) -> &mut Self
pub fn set_settings_bool(&mut self, val: BTreeMap<String, bool>) -> &mut Self
Boolean flag settings (e.g., disable_autosaves).
Sourcepub fn set_settings_number(&mut self, val: BTreeMap<String, i32>) -> &mut Self
pub fn set_settings_number(&mut self, val: BTreeMap<String, i32>) -> &mut Self
Integer settings (e.g., thresholds, limits).
Sourceimpl PackSettings
impl PackSettings
Sourcepub fn load(data: &[u8]) -> Result<Self>
pub fn load(data: &[u8]) -> Result<Self>
This function tries to load the settings from a slice and return them.
Sourcepub fn load_and_update(&mut self, data: &[u8]) -> Result<()>
pub fn load_and_update(&mut self, data: &[u8]) -> Result<()>
This function tries to load the settings from a slice, update them so they don’t have any missing values and return them.
Sourcepub fn setting_string(&self, key: &str) -> Option<&String>
pub fn setting_string(&self, key: &str) -> Option<&String>
This function returns the provided string setting, if found.
Sourcepub fn setting_text(&self, key: &str) -> Option<&String>
pub fn setting_text(&self, key: &str) -> Option<&String>
This function returns the provided text setting (multiline string), if found.
Sourcepub fn setting_bool(&self, key: &str) -> Option<&bool>
pub fn setting_bool(&self, key: &str) -> Option<&bool>
This function returns the provided bool setting, if found.
Sourcepub fn setting_number(&self, key: &str) -> Option<&i32>
pub fn setting_number(&self, key: &str) -> Option<&i32>
This function returns the provided numeric setting, if found.
Sourcepub fn set_setting_string(&mut self, key: &str, value: &str)
pub fn set_setting_string(&mut self, key: &str, value: &str)
This function sets the string setting provided with the value you passed.
If the value already existed, it gets overwritten.
Sourcepub fn set_setting_text(&mut self, key: &str, value: &str)
pub fn set_setting_text(&mut self, key: &str, value: &str)
This function sets the text (multiline string) setting provided with the value you passed.
If the value already existed, it gets overwritten.
Sourcepub fn set_setting_bool(&mut self, key: &str, value: bool)
pub fn set_setting_bool(&mut self, key: &str, value: bool)
This function sets the bool setting provided with the value you passed.
If the value already existed, it gets overwritten.
Sourcepub fn set_setting_number(&mut self, key: &str, value: i32)
pub fn set_setting_number(&mut self, key: &str, value: i32)
This function sets the numeric setting provided with the value you passed.
If the value already existed, it gets overwritten.