pub struct Variant { /* private fields */ }Expand description
A texture variant for a portrait entry.
Variants allow different portrait textures to be used based on game conditions such as season, character level, age, or faction role.
Implementations
Sourceimpl Variant
impl Variant
Sourcepub fn filename(&self) -> &String
pub fn filename(&self) -> &String
Variant identifier matching the variant_filename column in variants tables.
Sourcepub fn file_diffuse(&self) -> &String
pub fn file_diffuse(&self) -> &String
Path to the diffuse (color) texture for this variant.
Sourcepub fn file_mask_1(&self) -> &String
pub fn file_mask_1(&self) -> &String
Path to first mask texture (purpose unknown).
Sourcepub fn file_mask_2(&self) -> &String
pub fn file_mask_2(&self) -> &String
Path to second mask texture (purpose unknown).
Sourcepub fn file_mask_3(&self) -> &String
pub fn file_mask_3(&self) -> &String
Path to third mask texture (purpose unknown).
Sourcepub fn politician(&self) -> &bool
pub fn politician(&self) -> &bool
Whether this variant is for politicians. Only used in version 1.
Sourcepub fn faction_leader(&self) -> &bool
pub fn faction_leader(&self) -> &bool
Whether this variant is for faction leaders. Only used in version 1.
Sourceimpl Variant
impl Variant
Sourcepub fn filename_mut(&mut self) -> &mut String
pub fn filename_mut(&mut self) -> &mut String
Variant identifier matching the variant_filename column in variants tables.
Sourcepub fn file_diffuse_mut(&mut self) -> &mut String
pub fn file_diffuse_mut(&mut self) -> &mut String
Path to the diffuse (color) texture for this variant.
Sourcepub fn file_mask_1_mut(&mut self) -> &mut String
pub fn file_mask_1_mut(&mut self) -> &mut String
Path to first mask texture (purpose unknown).
Sourcepub fn file_mask_2_mut(&mut self) -> &mut String
pub fn file_mask_2_mut(&mut self) -> &mut String
Path to second mask texture (purpose unknown).
Sourcepub fn file_mask_3_mut(&mut self) -> &mut String
pub fn file_mask_3_mut(&mut self) -> &mut String
Path to third mask texture (purpose unknown).
Sourcepub fn season_mut(&mut self) -> &mut String
pub fn season_mut(&mut self) -> &mut String
Season when this variant applies. Only used in version 1.
Sourcepub fn politician_mut(&mut self) -> &mut bool
pub fn politician_mut(&mut self) -> &mut bool
Whether this variant is for politicians. Only used in version 1.
Sourcepub fn faction_leader_mut(&mut self) -> &mut bool
pub fn faction_leader_mut(&mut self) -> &mut bool
Whether this variant is for faction leaders. Only used in version 1.
Sourceimpl Variant
impl Variant
Sourcepub fn set_filename(&mut self, val: String) -> &mut Self
pub fn set_filename(&mut self, val: String) -> &mut Self
Variant identifier matching the variant_filename column in variants tables.
Sourcepub fn set_file_diffuse(&mut self, val: String) -> &mut Self
pub fn set_file_diffuse(&mut self, val: String) -> &mut Self
Path to the diffuse (color) texture for this variant.
Sourcepub fn set_file_mask_1(&mut self, val: String) -> &mut Self
pub fn set_file_mask_1(&mut self, val: String) -> &mut Self
Path to first mask texture (purpose unknown).
Sourcepub fn set_file_mask_2(&mut self, val: String) -> &mut Self
pub fn set_file_mask_2(&mut self, val: String) -> &mut Self
Path to second mask texture (purpose unknown).
Sourcepub fn set_file_mask_3(&mut self, val: String) -> &mut Self
pub fn set_file_mask_3(&mut self, val: String) -> &mut Self
Path to third mask texture (purpose unknown).
Sourcepub fn set_season(&mut self, val: String) -> &mut Self
pub fn set_season(&mut self, val: String) -> &mut Self
Season when this variant applies. Only used in version 1.
Sourcepub fn set_level(&mut self, val: i32) -> &mut Self
pub fn set_level(&mut self, val: i32) -> &mut Self
Character level threshold. Only used in version 1.
Sourcepub fn set_age(&mut self, val: i32) -> &mut Self
pub fn set_age(&mut self, val: i32) -> &mut Self
Character age threshold. Only used in version 1.
Sourcepub fn set_politician(&mut self, val: bool) -> &mut Self
pub fn set_politician(&mut self, val: bool) -> &mut Self
Whether this variant is for politicians. Only used in version 1.
Sourcepub fn set_faction_leader(&mut self, val: bool) -> &mut Self
pub fn set_faction_leader(&mut self, val: bool) -> &mut Self
Whether this variant is for faction leaders. Only used in version 1.