pub struct EventData { /* private fields */ }Expand description
Event data parameters.
Contains a large set of float parameters that define audio playback characteristics. The exact meaning of each parameter is not fully understood.
Implementations