pub struct SoundEvents { /* private fields */ }Expand description
Sound events configuration for a game.
Contains the complete audio event system configuration including categories, event definitions, ambience mappings, and movie audio settings.
Note: Many fields in this format are not fully understood and are marked as uk_*.
Implementations
Sourceimpl SoundEvents
impl SoundEvents
Sourcepub fn master_volume(&self) -> &f32
pub fn master_volume(&self) -> &f32
Master volume level for all sounds.
Sourcepub fn categories(&self) -> &Vec<Category>
pub fn categories(&self) -> &Vec<Category>
Sound categories (e.g., music, SFX, voice).
Sourcepub fn event_data(&self) -> &Vec<EventData>
pub fn event_data(&self) -> &Vec<EventData>
Event data parameters referenced by event records.
Sourcepub fn event_records(&self) -> &Vec<EventRecord>
pub fn event_records(&self) -> &Vec<EventRecord>
Sound event definitions.
Sourcepub fn ambience_map(&self) -> &Vec<AmbienceMap>
pub fn ambience_map(&self) -> &Vec<AmbienceMap>
Ambience sound mappings.
Sourceimpl SoundEvents
impl SoundEvents
Sourcepub fn master_volume_mut(&mut self) -> &mut f32
pub fn master_volume_mut(&mut self) -> &mut f32
Master volume level for all sounds.
Sourcepub fn categories_mut(&mut self) -> &mut Vec<Category>
pub fn categories_mut(&mut self) -> &mut Vec<Category>
Sound categories (e.g., music, SFX, voice).
Sourcepub fn event_data_mut(&mut self) -> &mut Vec<EventData>
pub fn event_data_mut(&mut self) -> &mut Vec<EventData>
Event data parameters referenced by event records.
Sourcepub fn event_records_mut(&mut self) -> &mut Vec<EventRecord>
pub fn event_records_mut(&mut self) -> &mut Vec<EventRecord>
Sound event definitions.
Sourcepub fn ambience_map_mut(&mut self) -> &mut Vec<AmbienceMap>
pub fn ambience_map_mut(&mut self) -> &mut Vec<AmbienceMap>
Ambience sound mappings.
Sourcepub fn movies_mut(&mut self) -> &mut Vec<Movie>
pub fn movies_mut(&mut self) -> &mut Vec<Movie>
Movie audio configurations.
Sourceimpl SoundEvents
impl SoundEvents
Sourcepub fn set_master_volume(&mut self, val: f32) -> &mut Self
pub fn set_master_volume(&mut self, val: f32) -> &mut Self
Master volume level for all sounds.
Sourcepub fn set_categories(&mut self, val: Vec<Category>) -> &mut Self
pub fn set_categories(&mut self, val: Vec<Category>) -> &mut Self
Sound categories (e.g., music, SFX, voice).
Sourcepub fn set_event_data(&mut self, val: Vec<EventData>) -> &mut Self
pub fn set_event_data(&mut self, val: Vec<EventData>) -> &mut Self
Event data parameters referenced by event records.
Sourcepub fn set_event_records(&mut self, val: Vec<EventRecord>) -> &mut Self
pub fn set_event_records(&mut self, val: Vec<EventRecord>) -> &mut Self
Sound event definitions.
Sourcepub fn set_ambience_map(&mut self, val: Vec<AmbienceMap>) -> &mut Self
pub fn set_ambience_map(&mut self, val: Vec<AmbienceMap>) -> &mut Self
Ambience sound mappings.
Sourcepub fn set_movies(&mut self, val: Vec<Movie>) -> &mut Self
pub fn set_movies(&mut self, val: Vec<Movie>) -> &mut Self
Movie audio configurations.