EncodeableExtraData

Struct EncodeableExtraData 

pub struct EncodeableExtraData<'a> { /* private fields */ }
This is a generic struct to easily pass additional data to a Encodeable::encode method.

To know what you need to provide to each file type, please check their documentation.

Implementations

Source

impl<'a> EncodeableExtraData<'a>

pub fn test_mode(&self) -> &bool

If we’re running the encode method on test mode.

pub fn nullify_dates(&self) -> &bool

If we want to set any date or timestamp to 0.

pub fn table_has_guid(&self) -> &bool

Only for tables. If we should add a GUID to its header or not.

pub fn regenerate_table_guid(&self) -> &bool

Only for tables. If we should regenerate the GUID of the table (if it even has one) or keep the current one.

pub fn game_info(&self) -> &Option<&'a GameInfo>

Full info of the game we’re trying to encode to.

pub fn compression_format(&self) -> &CompressionFormat

The format we’re trying to compress to, if we’re compressing the files.

pub fn disable_compression(&self) -> &bool

For recursive encodings in ESF due to compression.

Source

impl<'a> EncodeableExtraData<'a>

pub fn set_test_mode(&mut self, val: bool) -> &mut Self

If we’re running the encode method on test mode.

pub fn set_nullify_dates(&mut self, val: bool) -> &mut Self

If we want to set any date or timestamp to 0.

pub fn set_table_has_guid(&mut self, val: bool) -> &mut Self

Only for tables. If we should add a GUID to its header or not.

pub fn set_regenerate_table_guid(&mut self, val: bool) -> &mut Self

Only for tables. If we should regenerate the GUID of the table (if it even has one) or keep the current one.

pub fn set_game_info(&mut self, val: Option<&'a GameInfo>) -> &mut Self

Full info of the game we’re trying to encode to.

pub fn set_compression_format(&mut self, val: CompressionFormat) -> &mut Self

The format we’re trying to compress to, if we’re compressing the files.

pub fn set_disable_compression(&mut self, val: bool) -> &mut Self

For recursive encodings in ESF due to compression.

Source

impl<'a> EncodeableExtraData<'a>

pub fn new_from_game_info(game_info: &'a GameInfo) -> Self

This functions generates an EncodeableExtraData for a specific game.