pub struct EncodeableExtraData<'a> { /* private fields */ }Expand description
This is a generic struct to easily pass additional data to a Encodeable::encode method.
To know what you need to provide to each file type, please check their documentation.
Implementations
Sourceimpl<'a> EncodeableExtraData<'a>
impl<'a> EncodeableExtraData<'a>
Sourcepub fn nullify_dates(&self) -> &bool
pub fn nullify_dates(&self) -> &bool
If we want to set any date or timestamp to 0.
Sourcepub fn table_has_guid(&self) -> &bool
pub fn table_has_guid(&self) -> &bool
Only for tables. If we should add a GUID to its header or not.
Sourcepub fn regenerate_table_guid(&self) -> &bool
pub fn regenerate_table_guid(&self) -> &bool
Only for tables. If we should regenerate the GUID of the table (if it even has one) or keep the current one.
Sourcepub fn game_info(&self) -> &Option<&'a GameInfo>
pub fn game_info(&self) -> &Option<&'a GameInfo>
Full info of the game we’re trying to encode to.
Sourcepub fn compression_format(&self) -> &CompressionFormat
pub fn compression_format(&self) -> &CompressionFormat
The format we’re trying to compress to, if we’re compressing the files.
Sourcepub fn disable_compression(&self) -> &bool
pub fn disable_compression(&self) -> &bool
For recursive encodings in ESF due to compression.
Sourceimpl<'a> EncodeableExtraData<'a>
impl<'a> EncodeableExtraData<'a>
Sourcepub fn set_test_mode(&mut self, val: bool) -> &mut Self
pub fn set_test_mode(&mut self, val: bool) -> &mut Self
If we’re running the encode method on test mode.
Sourcepub fn set_nullify_dates(&mut self, val: bool) -> &mut Self
pub fn set_nullify_dates(&mut self, val: bool) -> &mut Self
If we want to set any date or timestamp to 0.
Sourcepub fn set_table_has_guid(&mut self, val: bool) -> &mut Self
pub fn set_table_has_guid(&mut self, val: bool) -> &mut Self
Only for tables. If we should add a GUID to its header or not.
Sourcepub fn set_regenerate_table_guid(&mut self, val: bool) -> &mut Self
pub fn set_regenerate_table_guid(&mut self, val: bool) -> &mut Self
Only for tables. If we should regenerate the GUID of the table (if it even has one) or keep the current one.
Sourcepub fn set_game_info(&mut self, val: Option<&'a GameInfo>) -> &mut Self
pub fn set_game_info(&mut self, val: Option<&'a GameInfo>) -> &mut Self
Full info of the game we’re trying to encode to.
Sourcepub fn set_compression_format(&mut self, val: CompressionFormat) -> &mut Self
pub fn set_compression_format(&mut self, val: CompressionFormat) -> &mut Self
The format we’re trying to compress to, if we’re compressing the files.
Sourcepub fn set_disable_compression(&mut self, val: bool) -> &mut Self
pub fn set_disable_compression(&mut self, val: bool) -> &mut Self
For recursive encodings in ESF due to compression.
Sourceimpl<'a> EncodeableExtraData<'a>
impl<'a> EncodeableExtraData<'a>
Sourcepub fn new_from_game_info(game_info: &'a GameInfo) -> Self
pub fn new_from_game_info(game_info: &'a GameInfo) -> Self
This functions generates an EncodeableExtraData for a specific game.