pub fn get_raw_localisable_fields_path(
current_path: &Path,
version: i16,
) -> Result<PathBuf>Expand description
Returns the path to the localisable fields metadata file.
This file (TExc_LocalisableFields.xml) contains the list of fields that should be
extracted to .loc translation files.
Arguments
current_path- Directory containing Assembly Kit filesversion- Assembly Kit version (1 or 2; version 0 is not supported)
Returns
Returns the path to the localisable fields file, or an error if not found.
Note
This file is optional in some Assembly Kits (notably absent in Warhammer 2).