pub struct RawLocalisableFields {
pub fields: Vec<RawLocalisableField>,
}Expand description
This is the raw equivalent to the entries field in a DB struct. In files, this is the equivalent to the .xml file with all the data in the table.
It contains a vector with all the rows of data in the .xml table file.
Fields
fields: Vec<RawLocalisableField>Implementations